# coding: utf-8

"""
    Swagger Blended Hub API Explorer

    A collection of Swagger documentation for the Blended Hub APIs.

    OpenAPI spec version: 1.0.0
    Contact: api@blended.co
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class BlendedPackage(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, href=None, pk=None, slug=None, account=None, name=None, type=None, base_package=None, is_published=None, package_status=None, description=None, rating_avg=None, rating_count=None, modified_date=None, created_date=None, user=None, title=None, purchase_pending=None, recipient=None, thumbnail_image=None, details_image=None, banner_image=None, canonical_version=None, is_set_canonical=None, licenses=None, ratings=None, dependencies=None, canonical=None, draft=None):
        """
        BlendedPackage - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'href': 'str',
            'pk': 'int',
            'slug': 'str',
            'account': 'str',
            'name': 'str',
            'type': 'str',
            'base_package': 'int',
            'is_published': 'bool',
            'package_status': 'str',
            'description': 'str',
            'rating_avg': 'float',
            'rating_count': 'float',
            'modified_date': 'datetime',
            'created_date': 'datetime',
            'user': 'str',
            'title': 'str',
            'purchase_pending': 'bool',
            'recipient': 'str',
            'thumbnail_image': 'str',
            'details_image': 'str',
            'banner_image': 'str',
            'canonical_version': 'str',
            'is_set_canonical': 'int',
            'licenses': 'object',
            'ratings': 'object',
            'dependencies': 'object',
            'canonical': 'object',
            'draft': 'object'
        }

        self.attribute_map = {
            'href': 'href',
            'pk': 'pk',
            'slug': 'slug',
            'account': 'account',
            'name': 'name',
            'type': 'type',
            'base_package': 'base_package',
            'is_published': 'is_published',
            'package_status': 'package_status',
            'description': 'description',
            'rating_avg': 'rating_avg',
            'rating_count': 'rating_count',
            'modified_date': 'modified_date',
            'created_date': 'created_date',
            'user': 'user',
            'title': 'title',
            'purchase_pending': 'purchase_pending',
            'recipient': 'recipient',
            'thumbnail_image': 'thumbnail_image',
            'details_image': 'details_image',
            'banner_image': 'banner_image',
            'canonical_version': 'canonical_version',
            'is_set_canonical': 'is_set_canonical',
            'licenses': 'licenses',
            'ratings': 'ratings',
            'dependencies': 'dependencies',
            'canonical': 'canonical',
            'draft': 'draft'
        }

        self._href = href
        self._pk = pk
        self._slug = slug
        self._account = account
        self._name = name
        self._type = type
        self._base_package = base_package
        self._is_published = is_published
        self._package_status = package_status
        self._description = description
        self._rating_avg = rating_avg
        self._rating_count = rating_count
        self._modified_date = modified_date
        self._created_date = created_date
        self._user = user
        self._title = title
        self._purchase_pending = purchase_pending
        self._recipient = recipient
        self._thumbnail_image = thumbnail_image
        self._details_image = details_image
        self._banner_image = banner_image
        self._canonical_version = canonical_version
        self._is_set_canonical = is_set_canonical
        self._licenses = licenses
        self._ratings = ratings
        self._dependencies = dependencies
        self._canonical = canonical
        self._draft = draft

    @property
    def href(self):
        """
        Gets the href of this BlendedPackage.
        current object reference url

        :return: The href of this BlendedPackage.
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """
        Sets the href of this BlendedPackage.
        current object reference url

        :param href: The href of this BlendedPackage.
        :type: str
        """

        self._href = href

    @property
    def pk(self):
        """
        Gets the pk of this BlendedPackage.
        value used to uniquely identify package.

        :return: The pk of this BlendedPackage.
        :rtype: int
        """
        return self._pk

    @pk.setter
    def pk(self, pk):
        """
        Sets the pk of this BlendedPackage.
        value used to uniquely identify package.

        :param pk: The pk of this BlendedPackage.
        :type: int
        """

        self._pk = pk

    @property
    def slug(self):
        """
        Gets the slug of this BlendedPackage.
        value used to uniquely identify package.

        :return: The slug of this BlendedPackage.
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """
        Sets the slug of this BlendedPackage.
        value used to uniquely identify package.

        :param slug: The slug of this BlendedPackage.
        :type: str
        """

        self._slug = slug

    @property
    def account(self):
        """
        Gets the account of this BlendedPackage.
        value used to uniquely identify account.

        :return: The account of this BlendedPackage.
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """
        Sets the account of this BlendedPackage.
        value used to uniquely identify account.

        :param account: The account of this BlendedPackage.
        :type: str
        """

        self._account = account

    @property
    def name(self):
        """
        Gets the name of this BlendedPackage.
        package name.

        :return: The name of this BlendedPackage.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this BlendedPackage.
        package name.

        :param name: The name of this BlendedPackage.
        :type: str
        """

        self._name = name

    @property
    def type(self):
        """
        Gets the type of this BlendedPackage.
        package type

        :return: The type of this BlendedPackage.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this BlendedPackage.
        package type

        :param type: The type of this BlendedPackage.
        :type: str
        """

        self._type = type

    @property
    def base_package(self):
        """
        Gets the base_package of this BlendedPackage.
        base package pk.

        :return: The base_package of this BlendedPackage.
        :rtype: int
        """
        return self._base_package

    @base_package.setter
    def base_package(self, base_package):
        """
        Sets the base_package of this BlendedPackage.
        base package pk.

        :param base_package: The base_package of this BlendedPackage.
        :type: int
        """

        self._base_package = base_package

    @property
    def is_published(self):
        """
        Gets the is_published of this BlendedPackage.
        package is published or not.

        :return: The is_published of this BlendedPackage.
        :rtype: bool
        """
        return self._is_published

    @is_published.setter
    def is_published(self, is_published):
        """
        Sets the is_published of this BlendedPackage.
        package is published or not.

        :param is_published: The is_published of this BlendedPackage.
        :type: bool
        """

        self._is_published = is_published

    @property
    def package_status(self):
        """
        Gets the package_status of this BlendedPackage.
        package status

        :return: The package_status of this BlendedPackage.
        :rtype: str
        """
        return self._package_status

    @package_status.setter
    def package_status(self, package_status):
        """
        Sets the package_status of this BlendedPackage.
        package status

        :param package_status: The package_status of this BlendedPackage.
        :type: str
        """

        self._package_status = package_status

    @property
    def description(self):
        """
        Gets the description of this BlendedPackage.
        package description.

        :return: The description of this BlendedPackage.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this BlendedPackage.
        package description.

        :param description: The description of this BlendedPackage.
        :type: str
        """

        self._description = description

    @property
    def rating_avg(self):
        """
        Gets the rating_avg of this BlendedPackage.
        average rating of package.

        :return: The rating_avg of this BlendedPackage.
        :rtype: float
        """
        return self._rating_avg

    @rating_avg.setter
    def rating_avg(self, rating_avg):
        """
        Sets the rating_avg of this BlendedPackage.
        average rating of package.

        :param rating_avg: The rating_avg of this BlendedPackage.
        :type: float
        """

        self._rating_avg = rating_avg

    @property
    def rating_count(self):
        """
        Gets the rating_count of this BlendedPackage.
        package total rating submitted.

        :return: The rating_count of this BlendedPackage.
        :rtype: float
        """
        return self._rating_count

    @rating_count.setter
    def rating_count(self, rating_count):
        """
        Sets the rating_count of this BlendedPackage.
        package total rating submitted.

        :param rating_count: The rating_count of this BlendedPackage.
        :type: float
        """

        self._rating_count = rating_count

    @property
    def modified_date(self):
        """
        Gets the modified_date of this BlendedPackage.
        last modified date.

        :return: The modified_date of this BlendedPackage.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this BlendedPackage.
        last modified date.

        :param modified_date: The modified_date of this BlendedPackage.
        :type: datetime
        """

        self._modified_date = modified_date

    @property
    def created_date(self):
        """
        Gets the created_date of this BlendedPackage.
        package creation date.

        :return: The created_date of this BlendedPackage.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this BlendedPackage.
        package creation date.

        :param created_date: The created_date of this BlendedPackage.
        :type: datetime
        """

        self._created_date = created_date

    @property
    def user(self):
        """
        Gets the user of this BlendedPackage.
        package creator name.

        :return: The user of this BlendedPackage.
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this BlendedPackage.
        package creator name.

        :param user: The user of this BlendedPackage.
        :type: str
        """

        self._user = user

    @property
    def title(self):
        """
        Gets the title of this BlendedPackage.
        package title.

        :return: The title of this BlendedPackage.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this BlendedPackage.
        package title.

        :param title: The title of this BlendedPackage.
        :type: str
        """

        self._title = title

    @property
    def purchase_pending(self):
        """
        Gets the purchase_pending of this BlendedPackage.
        used in transfer to me only for purchase pending lookup.

        :return: The purchase_pending of this BlendedPackage.
        :rtype: bool
        """
        return self._purchase_pending

    @purchase_pending.setter
    def purchase_pending(self, purchase_pending):
        """
        Sets the purchase_pending of this BlendedPackage.
        used in transfer to me only for purchase pending lookup.

        :param purchase_pending: The purchase_pending of this BlendedPackage.
        :type: bool
        """

        self._purchase_pending = purchase_pending

    @property
    def recipient(self):
        """
        Gets the recipient of this BlendedPackage.
        account slug or email of recipient.

        :return: The recipient of this BlendedPackage.
        :rtype: str
        """
        return self._recipient

    @recipient.setter
    def recipient(self, recipient):
        """
        Sets the recipient of this BlendedPackage.
        account slug or email of recipient.

        :param recipient: The recipient of this BlendedPackage.
        :type: str
        """

        self._recipient = recipient

    @property
    def thumbnail_image(self):
        """
        Gets the thumbnail_image of this BlendedPackage.
        

        :return: The thumbnail_image of this BlendedPackage.
        :rtype: str
        """
        return self._thumbnail_image

    @thumbnail_image.setter
    def thumbnail_image(self, thumbnail_image):
        """
        Sets the thumbnail_image of this BlendedPackage.
        

        :param thumbnail_image: The thumbnail_image of this BlendedPackage.
        :type: str
        """

        self._thumbnail_image = thumbnail_image

    @property
    def details_image(self):
        """
        Gets the details_image of this BlendedPackage.
        

        :return: The details_image of this BlendedPackage.
        :rtype: str
        """
        return self._details_image

    @details_image.setter
    def details_image(self, details_image):
        """
        Sets the details_image of this BlendedPackage.
        

        :param details_image: The details_image of this BlendedPackage.
        :type: str
        """

        self._details_image = details_image

    @property
    def banner_image(self):
        """
        Gets the banner_image of this BlendedPackage.
        Banner image of package

        :return: The banner_image of this BlendedPackage.
        :rtype: str
        """
        return self._banner_image

    @banner_image.setter
    def banner_image(self, banner_image):
        """
        Sets the banner_image of this BlendedPackage.
        Banner image of package

        :param banner_image: The banner_image of this BlendedPackage.
        :type: str
        """

        self._banner_image = banner_image

    @property
    def canonical_version(self):
        """
        Gets the canonical_version of this BlendedPackage.
        canonical_version of the package, most recent if canonical was not set.

        :return: The canonical_version of this BlendedPackage.
        :rtype: str
        """
        return self._canonical_version

    @canonical_version.setter
    def canonical_version(self, canonical_version):
        """
        Sets the canonical_version of this BlendedPackage.
        canonical_version of the package, most recent if canonical was not set.

        :param canonical_version: The canonical_version of this BlendedPackage.
        :type: str
        """

        self._canonical_version = canonical_version

    @property
    def is_set_canonical(self):
        """
        Gets the is_set_canonical of this BlendedPackage.
        flag to know if canonical version was set by user

        :return: The is_set_canonical of this BlendedPackage.
        :rtype: int
        """
        return self._is_set_canonical

    @is_set_canonical.setter
    def is_set_canonical(self, is_set_canonical):
        """
        Sets the is_set_canonical of this BlendedPackage.
        flag to know if canonical version was set by user

        :param is_set_canonical: The is_set_canonical of this BlendedPackage.
        :type: int
        """

        self._is_set_canonical = is_set_canonical

    @property
    def licenses(self):
        """
        Gets the licenses of this BlendedPackage.
        Package Licenses.

        :return: The licenses of this BlendedPackage.
        :rtype: object
        """
        return self._licenses

    @licenses.setter
    def licenses(self, licenses):
        """
        Sets the licenses of this BlendedPackage.
        Package Licenses.

        :param licenses: The licenses of this BlendedPackage.
        :type: object
        """

        self._licenses = licenses

    @property
    def ratings(self):
        """
        Gets the ratings of this BlendedPackage.
        Package ratings.

        :return: The ratings of this BlendedPackage.
        :rtype: object
        """
        return self._ratings

    @ratings.setter
    def ratings(self, ratings):
        """
        Sets the ratings of this BlendedPackage.
        Package ratings.

        :param ratings: The ratings of this BlendedPackage.
        :type: object
        """

        self._ratings = ratings

    @property
    def dependencies(self):
        """
        Gets the dependencies of this BlendedPackage.
        Package ratings.

        :return: The dependencies of this BlendedPackage.
        :rtype: object
        """
        return self._dependencies

    @dependencies.setter
    def dependencies(self, dependencies):
        """
        Sets the dependencies of this BlendedPackage.
        Package ratings.

        :param dependencies: The dependencies of this BlendedPackage.
        :type: object
        """

        self._dependencies = dependencies

    @property
    def canonical(self):
        """
        Gets the canonical of this BlendedPackage.
        Canonical Package Details.

        :return: The canonical of this BlendedPackage.
        :rtype: object
        """
        return self._canonical

    @canonical.setter
    def canonical(self, canonical):
        """
        Sets the canonical of this BlendedPackage.
        Canonical Package Details.

        :param canonical: The canonical of this BlendedPackage.
        :type: object
        """

        self._canonical = canonical

    @property
    def draft(self):
        """
        Gets the draft of this BlendedPackage.
        Canonical Package Details.

        :return: The draft of this BlendedPackage.
        :rtype: object
        """
        return self._draft

    @draft.setter
    def draft(self, draft):
        """
        Sets the draft of this BlendedPackage.
        Canonical Package Details.

        :param draft: The draft of this BlendedPackage.
        :type: object
        """

        self._draft = draft

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Swagger Blended Hub API Explorer

    A collection of Swagger documentation for the Blended Hub APIs.

    OpenAPI spec version: 1.0.0
    Contact: api@blended.co
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class CanonicalVersion(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, href=None, thumbnail_image=None, details_image=None, banner_image=None, description=None, rating_avg=None, rating_count=None, slug=None, account=None, name=None, type=None, title=None, pk=None, package=None, label=None, modified_date=None, created_date=None, user=None, validatorplan=None, documents=None, is_set_canonical=None, validation_status=None):
        """
        CanonicalVersion - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'href': 'str',
            'thumbnail_image': 'str',
            'details_image': 'str',
            'banner_image': 'str',
            'description': 'str',
            'rating_avg': 'float',
            'rating_count': 'float',
            'slug': 'str',
            'account': 'str',
            'name': 'str',
            'type': 'str',
            'title': 'str',
            'pk': 'int',
            'package': 'int',
            'label': 'str',
            'modified_date': 'datetime',
            'created_date': 'datetime',
            'user': 'str',
            'validatorplan': 'object',
            'documents': 'object',
            'is_set_canonical': 'int',
            'validation_status': 'str'
        }

        self.attribute_map = {
            'href': 'href',
            'thumbnail_image': 'thumbnail_image',
            'details_image': 'details_image',
            'banner_image': 'banner_image',
            'description': 'description',
            'rating_avg': 'rating_avg',
            'rating_count': 'rating_count',
            'slug': 'slug',
            'account': 'account',
            'name': 'name',
            'type': 'type',
            'title': 'title',
            'pk': 'pk',
            'package': 'package',
            'label': 'label',
            'modified_date': 'modified_date',
            'created_date': 'created_date',
            'user': 'user',
            'validatorplan': 'validatorplan',
            'documents': 'documents',
            'is_set_canonical': 'is_set_canonical',
            'validation_status': 'validation_status'
        }

        self._href = href
        self._thumbnail_image = thumbnail_image
        self._details_image = details_image
        self._banner_image = banner_image
        self._description = description
        self._rating_avg = rating_avg
        self._rating_count = rating_count
        self._slug = slug
        self._account = account
        self._name = name
        self._type = type
        self._title = title
        self._pk = pk
        self._package = package
        self._label = label
        self._modified_date = modified_date
        self._created_date = created_date
        self._user = user
        self._validatorplan = validatorplan
        self._documents = documents
        self._is_set_canonical = is_set_canonical
        self._validation_status = validation_status

    @property
    def href(self):
        """
        Gets the href of this CanonicalVersion.
        current object reference url

        :return: The href of this CanonicalVersion.
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """
        Sets the href of this CanonicalVersion.
        current object reference url

        :param href: The href of this CanonicalVersion.
        :type: str
        """

        self._href = href

    @property
    def thumbnail_image(self):
        """
        Gets the thumbnail_image of this CanonicalVersion.
        

        :return: The thumbnail_image of this CanonicalVersion.
        :rtype: str
        """
        return self._thumbnail_image

    @thumbnail_image.setter
    def thumbnail_image(self, thumbnail_image):
        """
        Sets the thumbnail_image of this CanonicalVersion.
        

        :param thumbnail_image: The thumbnail_image of this CanonicalVersion.
        :type: str
        """

        self._thumbnail_image = thumbnail_image

    @property
    def details_image(self):
        """
        Gets the details_image of this CanonicalVersion.
        

        :return: The details_image of this CanonicalVersion.
        :rtype: str
        """
        return self._details_image

    @details_image.setter
    def details_image(self, details_image):
        """
        Sets the details_image of this CanonicalVersion.
        

        :param details_image: The details_image of this CanonicalVersion.
        :type: str
        """

        self._details_image = details_image

    @property
    def banner_image(self):
        """
        Gets the banner_image of this CanonicalVersion.
        Banner image of package

        :return: The banner_image of this CanonicalVersion.
        :rtype: str
        """
        return self._banner_image

    @banner_image.setter
    def banner_image(self, banner_image):
        """
        Sets the banner_image of this CanonicalVersion.
        Banner image of package

        :param banner_image: The banner_image of this CanonicalVersion.
        :type: str
        """

        self._banner_image = banner_image

    @property
    def description(self):
        """
        Gets the description of this CanonicalVersion.
        package description.

        :return: The description of this CanonicalVersion.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CanonicalVersion.
        package description.

        :param description: The description of this CanonicalVersion.
        :type: str
        """

        self._description = description

    @property
    def rating_avg(self):
        """
        Gets the rating_avg of this CanonicalVersion.
        average rating of package.

        :return: The rating_avg of this CanonicalVersion.
        :rtype: float
        """
        return self._rating_avg

    @rating_avg.setter
    def rating_avg(self, rating_avg):
        """
        Sets the rating_avg of this CanonicalVersion.
        average rating of package.

        :param rating_avg: The rating_avg of this CanonicalVersion.
        :type: float
        """

        self._rating_avg = rating_avg

    @property
    def rating_count(self):
        """
        Gets the rating_count of this CanonicalVersion.
        package total rating submitted.

        :return: The rating_count of this CanonicalVersion.
        :rtype: float
        """
        return self._rating_count

    @rating_count.setter
    def rating_count(self, rating_count):
        """
        Sets the rating_count of this CanonicalVersion.
        package total rating submitted.

        :param rating_count: The rating_count of this CanonicalVersion.
        :type: float
        """

        self._rating_count = rating_count

    @property
    def slug(self):
        """
        Gets the slug of this CanonicalVersion.
        value used to uniquely identify package.

        :return: The slug of this CanonicalVersion.
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """
        Sets the slug of this CanonicalVersion.
        value used to uniquely identify package.

        :param slug: The slug of this CanonicalVersion.
        :type: str
        """

        self._slug = slug

    @property
    def account(self):
        """
        Gets the account of this CanonicalVersion.
        value used to uniquely identify account.

        :return: The account of this CanonicalVersion.
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """
        Sets the account of this CanonicalVersion.
        value used to uniquely identify account.

        :param account: The account of this CanonicalVersion.
        :type: str
        """

        self._account = account

    @property
    def name(self):
        """
        Gets the name of this CanonicalVersion.
        package name.

        :return: The name of this CanonicalVersion.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CanonicalVersion.
        package name.

        :param name: The name of this CanonicalVersion.
        :type: str
        """

        self._name = name

    @property
    def type(self):
        """
        Gets the type of this CanonicalVersion.
        package type

        :return: The type of this CanonicalVersion.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this CanonicalVersion.
        package type

        :param type: The type of this CanonicalVersion.
        :type: str
        """

        self._type = type

    @property
    def title(self):
        """
        Gets the title of this CanonicalVersion.
        package title.

        :return: The title of this CanonicalVersion.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this CanonicalVersion.
        package title.

        :param title: The title of this CanonicalVersion.
        :type: str
        """

        self._title = title

    @property
    def pk(self):
        """
        Gets the pk of this CanonicalVersion.
        unique identifier of version.

        :return: The pk of this CanonicalVersion.
        :rtype: int
        """
        return self._pk

    @pk.setter
    def pk(self, pk):
        """
        Sets the pk of this CanonicalVersion.
        unique identifier of version.

        :param pk: The pk of this CanonicalVersion.
        :type: int
        """

        self._pk = pk

    @property
    def package(self):
        """
        Gets the package of this CanonicalVersion.
        package pk.

        :return: The package of this CanonicalVersion.
        :rtype: int
        """
        return self._package

    @package.setter
    def package(self, package):
        """
        Sets the package of this CanonicalVersion.
        package pk.

        :param package: The package of this CanonicalVersion.
        :type: int
        """

        self._package = package

    @property
    def label(self):
        """
        Gets the label of this CanonicalVersion.
        version label.

        :return: The label of this CanonicalVersion.
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """
        Sets the label of this CanonicalVersion.
        version label.

        :param label: The label of this CanonicalVersion.
        :type: str
        """

        self._label = label

    @property
    def modified_date(self):
        """
        Gets the modified_date of this CanonicalVersion.
        last modified date.

        :return: The modified_date of this CanonicalVersion.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this CanonicalVersion.
        last modified date.

        :param modified_date: The modified_date of this CanonicalVersion.
        :type: datetime
        """

        self._modified_date = modified_date

    @property
    def created_date(self):
        """
        Gets the created_date of this CanonicalVersion.
        package  creation date.

        :return: The created_date of this CanonicalVersion.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this CanonicalVersion.
        package  creation date.

        :param created_date: The created_date of this CanonicalVersion.
        :type: datetime
        """

        self._created_date = created_date

    @property
    def user(self):
        """
        Gets the user of this CanonicalVersion.
        package version creator name.

        :return: The user of this CanonicalVersion.
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this CanonicalVersion.
        package version creator name.

        :param user: The user of this CanonicalVersion.
        :type: str
        """

        self._user = user

    @property
    def validatorplan(self):
        """
        Gets the validatorplan of this CanonicalVersion.
        Detail view of validatorplan.

        :return: The validatorplan of this CanonicalVersion.
        :rtype: object
        """
        return self._validatorplan

    @validatorplan.setter
    def validatorplan(self, validatorplan):
        """
        Sets the validatorplan of this CanonicalVersion.
        Detail view of validatorplan.

        :param validatorplan: The validatorplan of this CanonicalVersion.
        :type: object
        """

        self._validatorplan = validatorplan

    @property
    def documents(self):
        """
        Gets the documents of this CanonicalVersion.
        Document object.

        :return: The documents of this CanonicalVersion.
        :rtype: object
        """
        return self._documents

    @documents.setter
    def documents(self, documents):
        """
        Sets the documents of this CanonicalVersion.
        Document object.

        :param documents: The documents of this CanonicalVersion.
        :type: object
        """

        self._documents = documents

    @property
    def is_set_canonical(self):
        """
        Gets the is_set_canonical of this CanonicalVersion.
        flag to know if canonical version was set by user

        :return: The is_set_canonical of this CanonicalVersion.
        :rtype: int
        """
        return self._is_set_canonical

    @is_set_canonical.setter
    def is_set_canonical(self, is_set_canonical):
        """
        Sets the is_set_canonical of this CanonicalVersion.
        flag to know if canonical version was set by user

        :param is_set_canonical: The is_set_canonical of this CanonicalVersion.
        :type: int
        """

        self._is_set_canonical = is_set_canonical

    @property
    def validation_status(self):
        """
        Gets the validation_status of this CanonicalVersion.
        current validation status based on badge results and validation plans passing level

        :return: The validation_status of this CanonicalVersion.
        :rtype: str
        """
        return self._validation_status

    @validation_status.setter
    def validation_status(self, validation_status):
        """
        Sets the validation_status of this CanonicalVersion.
        current validation status based on badge results and validation plans passing level

        :param validation_status: The validation_status of this CanonicalVersion.
        :type: str
        """

        self._validation_status = validation_status

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Swagger Blended Hub API Explorer

    A collection of Swagger documentation for the Blended Hub APIs.

    OpenAPI spec version: 1.0.0
    Contact: api@blended.co
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class Acquisition(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, type=None, label=None, account_name=None, new_package_slug=None, new_package_title=None, license_name=None, email=None, message=None, auto_share_packages=None, purchase_packages=None):
        """
        Acquisition - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'type': 'str',
            'label': 'str',
            'account_name': 'str',
            'new_package_slug': 'str',
            'new_package_title': 'str',
            'license_name': 'str',
            'email': 'str',
            'message': 'str',
            'auto_share_packages': 'list[str]',
            'purchase_packages': 'list[str]'
        }

        self.attribute_map = {
            'type': 'type',
            'label': 'label',
            'account_name': 'account_name',
            'new_package_slug': 'new_package_slug',
            'new_package_title': 'new_package_title',
            'license_name': 'license_name',
            'email': 'email',
            'message': 'message',
            'auto_share_packages': 'auto_share_packages',
            'purchase_packages': 'purchase_packages'
        }

        self._type = type
        self._label = label
        self._account_name = account_name
        self._new_package_slug = new_package_slug
        self._new_package_title = new_package_title
        self._license_name = license_name
        self._email = email
        self._message = message
        self._auto_share_packages = auto_share_packages
        self._purchase_packages = purchase_packages

    @property
    def type(self):
        """
        Gets the type of this Acquisition.
        Type of acquisition user is going to create.Example : share, get,buy,transfer,extend and clone.

        :return: The type of this Acquisition.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this Acquisition.
        Type of acquisition user is going to create.Example : share, get,buy,transfer,extend and clone.

        :param type: The type of this Acquisition.
        :type: str
        """

        self._type = type

    @property
    def label(self):
        """
        Gets the label of this Acquisition.
        version of the package for clone. 

        :return: The label of this Acquisition.
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """
        Sets the label of this Acquisition.
        version of the package for clone. 

        :param label: The label of this Acquisition.
        :type: str
        """

        self._label = label

    @property
    def account_name(self):
        """
        Gets the account_name of this Acquisition.
        Name of the account where user wants to share or transfer package.

        :return: The account_name of this Acquisition.
        :rtype: str
        """
        return self._account_name

    @account_name.setter
    def account_name(self, account_name):
        """
        Sets the account_name of this Acquisition.
        Name of the account where user wants to share or transfer package.

        :param account_name: The account_name of this Acquisition.
        :type: str
        """

        self._account_name = account_name

    @property
    def new_package_slug(self):
        """
        Gets the new_package_slug of this Acquisition.
        new package name used in clone and extend package.

        :return: The new_package_slug of this Acquisition.
        :rtype: str
        """
        return self._new_package_slug

    @new_package_slug.setter
    def new_package_slug(self, new_package_slug):
        """
        Sets the new_package_slug of this Acquisition.
        new package name used in clone and extend package.

        :param new_package_slug: The new_package_slug of this Acquisition.
        :type: str
        """

        self._new_package_slug = new_package_slug

    @property
    def new_package_title(self):
        """
        Gets the new_package_title of this Acquisition.
        new package title used in clone and extend package.

        :return: The new_package_title of this Acquisition.
        :rtype: str
        """
        return self._new_package_title

    @new_package_title.setter
    def new_package_title(self, new_package_title):
        """
        Sets the new_package_title of this Acquisition.
        new package title used in clone and extend package.

        :param new_package_title: The new_package_title of this Acquisition.
        :type: str
        """

        self._new_package_title = new_package_title

    @property
    def license_name(self):
        """
        Gets the license_name of this Acquisition.
        Name of the license used to buy or get package.

        :return: The license_name of this Acquisition.
        :rtype: str
        """
        return self._license_name

    @license_name.setter
    def license_name(self, license_name):
        """
        Sets the license_name of this Acquisition.
        Name of the license used to buy or get package.

        :param license_name: The license_name of this Acquisition.
        :type: str
        """

        self._license_name = license_name

    @property
    def email(self):
        """
        Gets the email of this Acquisition.
        Email address for Inviting user via email.

        :return: The email of this Acquisition.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this Acquisition.
        Email address for Inviting user via email.

        :param email: The email of this Acquisition.
        :type: str
        """

        self._email = email

    @property
    def message(self):
        """
        Gets the message of this Acquisition.
        Message will be send with the invite in the email.

        :return: The message of this Acquisition.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this Acquisition.
        Message will be send with the invite in the email.

        :param message: The message of this Acquisition.
        :type: str
        """

        self._message = message

    @property
    def auto_share_packages(self):
        """
        Gets the auto_share_packages of this Acquisition.
        list of dependency packages which needs to shared.

        :return: The auto_share_packages of this Acquisition.
        :rtype: list[str]
        """
        return self._auto_share_packages

    @auto_share_packages.setter
    def auto_share_packages(self, auto_share_packages):
        """
        Sets the auto_share_packages of this Acquisition.
        list of dependency packages which needs to shared.

        :param auto_share_packages: The auto_share_packages of this Acquisition.
        :type: list[str]
        """

        self._auto_share_packages = auto_share_packages

    @property
    def purchase_packages(self):
        """
        Gets the purchase_packages of this Acquisition.
        list of dependency packages which needs to purchases.

        :return: The purchase_packages of this Acquisition.
        :rtype: list[str]
        """
        return self._purchase_packages

    @purchase_packages.setter
    def purchase_packages(self, purchase_packages):
        """
        Sets the purchase_packages of this Acquisition.
        list of dependency packages which needs to purchases.

        :param purchase_packages: The purchase_packages of this Acquisition.
        :type: list[str]
        """

        self._purchase_packages = purchase_packages

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Swagger Blended Hub API Explorer

    A collection of Swagger documentation for the Blended Hub APIs.

    OpenAPI spec version: 1.0.0
    Contact: api@blended.co
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class RejectAcquisitionPackage(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, action=None, unknown_person=None, not_intended_for_me=None, do_not_want_it=None, derogatory_language=None, sexual_explicit=None, harassment=None, hateful_content=None, child_abuse=None, unwanted_commercial_or_spam=None, other=None):
        """
        RejectAcquisitionPackage - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'action': 'str',
            'unknown_person': 'bool',
            'not_intended_for_me': 'bool',
            'do_not_want_it': 'bool',
            'derogatory_language': 'bool',
            'sexual_explicit': 'bool',
            'harassment': 'bool',
            'hateful_content': 'bool',
            'child_abuse': 'bool',
            'unwanted_commercial_or_spam': 'bool',
            'other': 'str'
        }

        self.attribute_map = {
            'action': 'action',
            'unknown_person': 'unknown_person',
            'not_intended_for_me': 'not_intended_for_me',
            'do_not_want_it': 'do_not_want_it',
            'derogatory_language': 'derogatory_language',
            'sexual_explicit': 'sexual_explicit',
            'harassment': 'harassment',
            'hateful_content': 'hateful_content',
            'child_abuse': 'child_abuse',
            'unwanted_commercial_or_spam': 'unwanted_commercial_or_spam',
            'other': 'other'
        }

        self._action = action
        self._unknown_person = unknown_person
        self._not_intended_for_me = not_intended_for_me
        self._do_not_want_it = do_not_want_it
        self._derogatory_language = derogatory_language
        self._sexual_explicit = sexual_explicit
        self._harassment = harassment
        self._hateful_content = hateful_content
        self._child_abuse = child_abuse
        self._unwanted_commercial_or_spam = unwanted_commercial_or_spam
        self._other = other

    @property
    def action(self):
        """
        Gets the action of this RejectAcquisitionPackage.
        Type of acquisition user is going to reject.Example : share, get,buy,transfer,extend and clone.

        :return: The action of this RejectAcquisitionPackage.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this RejectAcquisitionPackage.
        Type of acquisition user is going to reject.Example : share, get,buy,transfer,extend and clone.

        :param action: The action of this RejectAcquisitionPackage.
        :type: str
        """

        self._action = action

    @property
    def unknown_person(self):
        """
        Gets the unknown_person of this RejectAcquisitionPackage.
        When reason to reject is 'I do not know the person who shared this with me'.

        :return: The unknown_person of this RejectAcquisitionPackage.
        :rtype: bool
        """
        return self._unknown_person

    @unknown_person.setter
    def unknown_person(self, unknown_person):
        """
        Sets the unknown_person of this RejectAcquisitionPackage.
        When reason to reject is 'I do not know the person who shared this with me'.

        :param unknown_person: The unknown_person of this RejectAcquisitionPackage.
        :type: bool
        """

        self._unknown_person = unknown_person

    @property
    def not_intended_for_me(self):
        """
        Gets the not_intended_for_me of this RejectAcquisitionPackage.
        when the reason to reject is 'It was not intended for me'.

        :return: The not_intended_for_me of this RejectAcquisitionPackage.
        :rtype: bool
        """
        return self._not_intended_for_me

    @not_intended_for_me.setter
    def not_intended_for_me(self, not_intended_for_me):
        """
        Sets the not_intended_for_me of this RejectAcquisitionPackage.
        when the reason to reject is 'It was not intended for me'.

        :param not_intended_for_me: The not_intended_for_me of this RejectAcquisitionPackage.
        :type: bool
        """

        self._not_intended_for_me = not_intended_for_me

    @property
    def do_not_want_it(self):
        """
        Gets the do_not_want_it of this RejectAcquisitionPackage.
        when the reason to reject is 'I do not want it; it is clogging up my list'.

        :return: The do_not_want_it of this RejectAcquisitionPackage.
        :rtype: bool
        """
        return self._do_not_want_it

    @do_not_want_it.setter
    def do_not_want_it(self, do_not_want_it):
        """
        Sets the do_not_want_it of this RejectAcquisitionPackage.
        when the reason to reject is 'I do not want it; it is clogging up my list'.

        :param do_not_want_it: The do_not_want_it of this RejectAcquisitionPackage.
        :type: bool
        """

        self._do_not_want_it = do_not_want_it

    @property
    def derogatory_language(self):
        """
        Gets the derogatory_language of this RejectAcquisitionPackage.
        when the reason to reject is 'Derogatory Language'.

        :return: The derogatory_language of this RejectAcquisitionPackage.
        :rtype: bool
        """
        return self._derogatory_language

    @derogatory_language.setter
    def derogatory_language(self, derogatory_language):
        """
        Sets the derogatory_language of this RejectAcquisitionPackage.
        when the reason to reject is 'Derogatory Language'.

        :param derogatory_language: The derogatory_language of this RejectAcquisitionPackage.
        :type: bool
        """

        self._derogatory_language = derogatory_language

    @property
    def sexual_explicit(self):
        """
        Gets the sexual_explicit of this RejectAcquisitionPackage.
        when the reason to reject is 'Sexual explicit or pornographic content'.

        :return: The sexual_explicit of this RejectAcquisitionPackage.
        :rtype: bool
        """
        return self._sexual_explicit

    @sexual_explicit.setter
    def sexual_explicit(self, sexual_explicit):
        """
        Sets the sexual_explicit of this RejectAcquisitionPackage.
        when the reason to reject is 'Sexual explicit or pornographic content'.

        :param sexual_explicit: The sexual_explicit of this RejectAcquisitionPackage.
        :type: bool
        """

        self._sexual_explicit = sexual_explicit

    @property
    def harassment(self):
        """
        Gets the harassment of this RejectAcquisitionPackage.
        when the reason to reject is 'Harassment or bullying'.

        :return: The harassment of this RejectAcquisitionPackage.
        :rtype: bool
        """
        return self._harassment

    @harassment.setter
    def harassment(self, harassment):
        """
        Sets the harassment of this RejectAcquisitionPackage.
        when the reason to reject is 'Harassment or bullying'.

        :param harassment: The harassment of this RejectAcquisitionPackage.
        :type: bool
        """

        self._harassment = harassment

    @property
    def hateful_content(self):
        """
        Gets the hateful_content of this RejectAcquisitionPackage.
        when the reason to reject is 'Hateful or violent content'.

        :return: The hateful_content of this RejectAcquisitionPackage.
        :rtype: bool
        """
        return self._hateful_content

    @hateful_content.setter
    def hateful_content(self, hateful_content):
        """
        Sets the hateful_content of this RejectAcquisitionPackage.
        when the reason to reject is 'Hateful or violent content'.

        :param hateful_content: The hateful_content of this RejectAcquisitionPackage.
        :type: bool
        """

        self._hateful_content = hateful_content

    @property
    def child_abuse(self):
        """
        Gets the child_abuse of this RejectAcquisitionPackage.
        when the reason to reject is 'Child Abuse'.

        :return: The child_abuse of this RejectAcquisitionPackage.
        :rtype: bool
        """
        return self._child_abuse

    @child_abuse.setter
    def child_abuse(self, child_abuse):
        """
        Sets the child_abuse of this RejectAcquisitionPackage.
        when the reason to reject is 'Child Abuse'.

        :param child_abuse: The child_abuse of this RejectAcquisitionPackage.
        :type: bool
        """

        self._child_abuse = child_abuse

    @property
    def unwanted_commercial_or_spam(self):
        """
        Gets the unwanted_commercial_or_spam of this RejectAcquisitionPackage.
        when the reason to reject is 'Unwanted Commercial content or spam'.

        :return: The unwanted_commercial_or_spam of this RejectAcquisitionPackage.
        :rtype: bool
        """
        return self._unwanted_commercial_or_spam

    @unwanted_commercial_or_spam.setter
    def unwanted_commercial_or_spam(self, unwanted_commercial_or_spam):
        """
        Sets the unwanted_commercial_or_spam of this RejectAcquisitionPackage.
        when the reason to reject is 'Unwanted Commercial content or spam'.

        :param unwanted_commercial_or_spam: The unwanted_commercial_or_spam of this RejectAcquisitionPackage.
        :type: bool
        """

        self._unwanted_commercial_or_spam = unwanted_commercial_or_spam

    @property
    def other(self):
        """
        Gets the other of this RejectAcquisitionPackage.
        When user is rejecting package with his/her own reason he/she will mention that message in other field.

        :return: The other of this RejectAcquisitionPackage.
        :rtype: str
        """
        return self._other

    @other.setter
    def other(self, other):
        """
        Sets the other of this RejectAcquisitionPackage.
        When user is rejecting package with his/her own reason he/she will mention that message in other field.

        :param other: The other of this RejectAcquisitionPackage.
        :type: str
        """

        self._other = other

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



import os
STATIC_DIR = os.path.join(os.path.abspath(os.path.dirname(__file__)), "static")
blended_static_dir = STATIC_DIR
# "" #user can modified it as per there choice
CSS_DIRECTORY = os.path.join(STATIC_DIR, "css")
IMAGE_CACHE_DIR = os.path.join(STATIC_DIR, "media")
COMPILE_DIR = os.path.join(CSS_DIRECTORY, "blended")



# coding: utf-8

"""
    Swagger Blended Hub API Explorer

    A collection of Swagger documentation for the Blended Hub APIs.

    OpenAPI spec version: 1.0.0
    Contact: api@blended.co
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class SearchResult(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, href=None, pk=None, name=None, slug=None, account=None, type=None, is_liked=None, package_status=None, description=None, rating_avg=None, title=None, rating_count=None, modified_date=None, created_date=None, user=None, thumbnail_image=None, details_image=None, banner_image=None, all_licenses_price=None, ratings=None):
        """
        SearchResult - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'href': 'str',
            'pk': 'int',
            'name': 'str',
            'slug': 'str',
            'account': 'str',
            'type': 'str',
            'is_liked': 'bool',
            'package_status': 'str',
            'description': 'str',
            'rating_avg': 'float',
            'title': 'str',
            'rating_count': 'float',
            'modified_date': 'datetime',
            'created_date': 'datetime',
            'user': 'str',
            'thumbnail_image': 'str',
            'details_image': 'str',
            'banner_image': 'str',
            'all_licenses_price': 'list[AllLicensePrice]',
            'ratings': 'object'
        }

        self.attribute_map = {
            'href': 'href',
            'pk': 'pk',
            'name': 'name',
            'slug': 'slug',
            'account': 'account',
            'type': 'type',
            'is_liked': 'is_liked',
            'package_status': 'package_status',
            'description': 'description',
            'rating_avg': 'rating_avg',
            'title': 'title',
            'rating_count': 'rating_count',
            'modified_date': 'modified_date',
            'created_date': 'created_date',
            'user': 'user',
            'thumbnail_image': 'thumbnail_image',
            'details_image': 'details_image',
            'banner_image': 'banner_image',
            'all_licenses_price': 'all_licenses_price',
            'ratings': 'ratings'
        }

        self._href = href
        self._pk = pk
        self._name = name
        self._slug = slug
        self._account = account
        self._type = type
        self._is_liked = is_liked
        self._package_status = package_status
        self._description = description
        self._rating_avg = rating_avg
        self._title = title
        self._rating_count = rating_count
        self._modified_date = modified_date
        self._created_date = created_date
        self._user = user
        self._thumbnail_image = thumbnail_image
        self._details_image = details_image
        self._banner_image = banner_image
        self._all_licenses_price = all_licenses_price
        self._ratings = ratings

    @property
    def href(self):
        """
        Gets the href of this SearchResult.
        current object reference url

        :return: The href of this SearchResult.
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """
        Sets the href of this SearchResult.
        current object reference url

        :param href: The href of this SearchResult.
        :type: str
        """

        self._href = href

    @property
    def pk(self):
        """
        Gets the pk of this SearchResult.
        unique identifier of package.

        :return: The pk of this SearchResult.
        :rtype: int
        """
        return self._pk

    @pk.setter
    def pk(self, pk):
        """
        Sets the pk of this SearchResult.
        unique identifier of package.

        :param pk: The pk of this SearchResult.
        :type: int
        """

        self._pk = pk

    @property
    def name(self):
        """
        Gets the name of this SearchResult.
        package name.

        :return: The name of this SearchResult.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SearchResult.
        package name.

        :param name: The name of this SearchResult.
        :type: str
        """

        self._name = name

    @property
    def slug(self):
        """
        Gets the slug of this SearchResult.
        value used to uniquely identify package.

        :return: The slug of this SearchResult.
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """
        Sets the slug of this SearchResult.
        value used to uniquely identify package.

        :param slug: The slug of this SearchResult.
        :type: str
        """

        self._slug = slug

    @property
    def account(self):
        """
        Gets the account of this SearchResult.
        value used to uniquely identify account.

        :return: The account of this SearchResult.
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """
        Sets the account of this SearchResult.
        value used to uniquely identify account.

        :param account: The account of this SearchResult.
        :type: str
        """

        self._account = account

    @property
    def type(self):
        """
        Gets the type of this SearchResult.
        package type

        :return: The type of this SearchResult.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this SearchResult.
        package type

        :param type: The type of this SearchResult.
        :type: str
        """

        self._type = type

    @property
    def is_liked(self):
        """
        Gets the is_liked of this SearchResult.
        whether the package was liked or not

        :return: The is_liked of this SearchResult.
        :rtype: bool
        """
        return self._is_liked

    @is_liked.setter
    def is_liked(self, is_liked):
        """
        Sets the is_liked of this SearchResult.
        whether the package was liked or not

        :param is_liked: The is_liked of this SearchResult.
        :type: bool
        """

        self._is_liked = is_liked

    @property
    def package_status(self):
        """
        Gets the package_status of this SearchResult.
        package status

        :return: The package_status of this SearchResult.
        :rtype: str
        """
        return self._package_status

    @package_status.setter
    def package_status(self, package_status):
        """
        Sets the package_status of this SearchResult.
        package status

        :param package_status: The package_status of this SearchResult.
        :type: str
        """

        self._package_status = package_status

    @property
    def description(self):
        """
        Gets the description of this SearchResult.
        package description

        :return: The description of this SearchResult.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this SearchResult.
        package description

        :param description: The description of this SearchResult.
        :type: str
        """

        self._description = description

    @property
    def rating_avg(self):
        """
        Gets the rating_avg of this SearchResult.
        average rating.

        :return: The rating_avg of this SearchResult.
        :rtype: float
        """
        return self._rating_avg

    @rating_avg.setter
    def rating_avg(self, rating_avg):
        """
        Sets the rating_avg of this SearchResult.
        average rating.

        :param rating_avg: The rating_avg of this SearchResult.
        :type: float
        """

        self._rating_avg = rating_avg

    @property
    def title(self):
        """
        Gets the title of this SearchResult.
        package title.

        :return: The title of this SearchResult.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this SearchResult.
        package title.

        :param title: The title of this SearchResult.
        :type: str
        """

        self._title = title

    @property
    def rating_count(self):
        """
        Gets the rating_count of this SearchResult.
        package total rating submitted.

        :return: The rating_count of this SearchResult.
        :rtype: float
        """
        return self._rating_count

    @rating_count.setter
    def rating_count(self, rating_count):
        """
        Sets the rating_count of this SearchResult.
        package total rating submitted.

        :param rating_count: The rating_count of this SearchResult.
        :type: float
        """

        self._rating_count = rating_count

    @property
    def modified_date(self):
        """
        Gets the modified_date of this SearchResult.
        last modified date.

        :return: The modified_date of this SearchResult.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this SearchResult.
        last modified date.

        :param modified_date: The modified_date of this SearchResult.
        :type: datetime
        """

        self._modified_date = modified_date

    @property
    def created_date(self):
        """
        Gets the created_date of this SearchResult.
        account creation date.

        :return: The created_date of this SearchResult.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this SearchResult.
        account creation date.

        :param created_date: The created_date of this SearchResult.
        :type: datetime
        """

        self._created_date = created_date

    @property
    def user(self):
        """
        Gets the user of this SearchResult.
        package creator name.

        :return: The user of this SearchResult.
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this SearchResult.
        package creator name.

        :param user: The user of this SearchResult.
        :type: str
        """

        self._user = user

    @property
    def thumbnail_image(self):
        """
        Gets the thumbnail_image of this SearchResult.
        

        :return: The thumbnail_image of this SearchResult.
        :rtype: str
        """
        return self._thumbnail_image

    @thumbnail_image.setter
    def thumbnail_image(self, thumbnail_image):
        """
        Sets the thumbnail_image of this SearchResult.
        

        :param thumbnail_image: The thumbnail_image of this SearchResult.
        :type: str
        """

        self._thumbnail_image = thumbnail_image

    @property
    def details_image(self):
        """
        Gets the details_image of this SearchResult.
        

        :return: The details_image of this SearchResult.
        :rtype: str
        """
        return self._details_image

    @details_image.setter
    def details_image(self, details_image):
        """
        Sets the details_image of this SearchResult.
        

        :param details_image: The details_image of this SearchResult.
        :type: str
        """

        self._details_image = details_image

    @property
    def banner_image(self):
        """
        Gets the banner_image of this SearchResult.
        Banner image of the package.

        :return: The banner_image of this SearchResult.
        :rtype: str
        """
        return self._banner_image

    @banner_image.setter
    def banner_image(self, banner_image):
        """
        Sets the banner_image of this SearchResult.
        Banner image of the package.

        :param banner_image: The banner_image of this SearchResult.
        :type: str
        """

        self._banner_image = banner_image

    @property
    def all_licenses_price(self):
        """
        Gets the all_licenses_price of this SearchResult.
        detail view of each search result.

        :return: The all_licenses_price of this SearchResult.
        :rtype: list[AllLicensePrice]
        """
        return self._all_licenses_price

    @all_licenses_price.setter
    def all_licenses_price(self, all_licenses_price):
        """
        Sets the all_licenses_price of this SearchResult.
        detail view of each search result.

        :param all_licenses_price: The all_licenses_price of this SearchResult.
        :type: list[AllLicensePrice]
        """

        self._all_licenses_price = all_licenses_price

    @property
    def ratings(self):
        """
        Gets the ratings of this SearchResult.
        Package ratings.

        :return: The ratings of this SearchResult.
        :rtype: object
        """
        return self._ratings

    @ratings.setter
    def ratings(self, ratings):
        """
        Sets the ratings of this SearchResult.
        Package ratings.

        :param ratings: The ratings of this SearchResult.
        :type: object
        """

        self._ratings = ratings

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



import os
import sys
from blendedUx.blended_flask.blended_hostlib.backend import FileSystemBackend
from blendedUx.blended_flask.blended_hostlib.network import Network
from blendedUx.blended_flask.blended_hostlib.controller import Controller
from blendedUx.blended_flask.blended_hostlib.exceptions import BlendedException, \
    PackageNameExistsException, AccountActivationException


class Route(object):
    """
    This is route class, an intermediary between CLI and Hostlib.
    """
    def __init__(self, account, package):
        """
        Initialization method of Route class.
        """
        blended_dir = account.blended_dir
        self.user_slug = account.user_slug
        self.current_account = account.current_account
        last_active = account.last_active
        current_dir = account.current_dir
        self.backend = FileSystemBackend(
                 current_dir, blended_dir=blended_dir,
                 current_account=self.current_account, blended_directory_path=blended_dir,
                 last_login=last_active)
        self.controller = Controller(Network(), self.backend)

    def sync_file_path(self, path_list):
        """
        The sync_file_path function is used to sync file_path.
        With particular os(windows, ubuntu, mac).When we use file flag in pull/push.
        """
        new_path_list = []
        for item in path_list:
            item = item.replace('/', os.sep)
            new_path_list.append(item)
        return new_path_list

    def install_package(self, account, package):
        """
        Adds/install the specified package into the local dependencies directory (lib).
        If no label is specified, then the canonical snapshot is assumed.
        This will recursively install all dependencies of the specified package as well.
        """
        package_name = package.package_name
        package_id = package.package_id
        label = package.label
        response = self.controller.install_package(package_name,
                                                   user_slug=self.user_slug,
                                                   label=label,
                                                   current_account=self.current_account)
        return response

    def create_package(self, account, package):
        """
        Creates a new package.
        """
        package_name = package.package_name
        package_title = package.package_title
        package_description = package.package_description
        package_type_name = package.package_type_name
        primary_category = package.primary_category
        secondary_category = package.secondary_category
        response, error_list = self.controller.create_package(self.current_account,
                                                              package_name,
                                                              package_type_name,
                                                              package_description,
                                                              package_title,
                                                              primary_category,
                                                              secondary_category)
        return response, error_list

    def packages_list(self, account, package):
        """
        Lists all of the packages available to the current user in the current account,
        unless --account is specified,
        in which case the specified account's contents are specified.
        """
        account_name = account.account_name
        package_name = package.package_name
        share = package.share
        transfer_by_me = package.transfer_by_me
        transfer_to_me = package.transfer_to_me
        organization = package.organization
        published = package.published
        purchased = package.purchased
        response = None
        if self.current_account == 'anonymous':
            account_name = 'anonymous'
        if(not account_name):
            try:
                account_name = self.controller.get_current_account(self.user_slug).slug
            except BlendedException as exc:
                raise BlendedException(exc)
        if package_name:
            response = self.controller.package_accounts_list(account_name, package_name=package_name)
        else:
            response = self.controller.packages_list(account_name, transfer_to_me=transfer_to_me,
                                                transfer_by_me=transfer_by_me, share=share, 
                                                organization=organization, published=published,
                                                purchased=purchased)
        return response

    def get_package_acquisition(self, account, package):
        """
        Adds the specified package into the library of the current account;
        similar to clone, except that it links the account to a specific license of the specified package.
        """
        package_name = package.package_name
        new_name = package.new_name
        package_id = package.package_id
        license_name = package.license_name
        label = package.label
        response = self.controller.get_package_acquisition(
                            package_name, license_name=license_name,
                            new_name=new_name, current_account=self.current_account, label=label)
        return response

    def package_clone(self, account, package):
        """
        it clones a package if the name exists then new-name is required with --new-name flag.
        It pull package in local src.
        """
        cloned_package_name = package.cloned_package_name
        package_name = package.package_name
        new_name = package.new_name
        package_id = package.package_id
        package_title = package.package_title
        label = package.label
        no_download = package.no_download
        package_description = package.package_description
        draft = package.draft
        primary_category = package.primary_category
        secondary_category = package.secondary_category
        response = self.controller.package_clone(
                        package_name, new_name=new_name, draft=draft, label=label,
                        description=package_description, current_account=self.current_account,
                        package_title=package_title, primary_category=primary_category,
                        secondary_category=secondary_category)
        return response
 
 
    def package_type(self, package_name, label, draft):
        """
        """
        package_name = package_name
        label = label
        draft = draft
        response = self.controller.get_type(
                        package_name, draft=draft, label=label,
                        current_account=self.current_account
                        )
        return response

    def package_extend(self, account, package):
        """
        A new package is created that includes the referenced package as a dependency, with an alias of "parent".
        """
        package_name = package.package_name
        new_name = package.new_name
        package_id = package.package_id
        label = package.label
        package_description = package.package_description
        draft = package.draft
        package_type = package.package_type
        package_title = package.package_title
        response = self.controller.package_extend(package_name,
                                                  new_name=new_name,
                                                  draft=draft,
                                                  label=label,
                                                  description=package_description,
                                                  current_account=self.current_account,
                                                  package_type=package_type,
                                                  package_title=package_title,
                                                  )
        return response

    def pull_package(self, account, package, **kwargs):
        """
        Downloads the specified package into blended/src, and all dependencies into either blended/lib or
        blended/src, depending on the rules. clone internally call pull_package with "new_name".
        """
        hub_pack = kwargs.get('pack', None)
        package_name = package.package_name
        package_id = package.package_id
        label = package.label
        draft = package.draft
        update = package.update
        force = package.force
        files = package.files
        new_name = package.new_name
        if new_name:
            package_name = new_name
        replace_from_local_list = package.replace_from_local_list
        if label:
            try:
                response = self.controller.package_clone(
                        package_name, new_name=new_name, draft=False, label=label,
                        description=None, current_account=self.current_account, action="pull")
            except BlendedException as exc:
                try:
                    raise BlendedException(exc.args[0].args[0].args[0])
                except IndexError:
                    raise BlendedException(exc)
            return response
        if files:
            response = self.controller.pull_package(package_name,
                                               force, draft=draft, user_slug=self.user_slug,
                                               label=label, current_account=self.current_account, files=files)
        elif replace_from_local_list:
            location = []
            for item in replace_from_local_list:
                location.append((item.location.split(package_name)[1].lstrip(os.sep)).replace(os.sep, "/"))
            response = self.controller.pull_package(package_name,
                                               force, draft=draft, user_slug=self.user_slug,
                                               label=label, current_account=self.current_account,
                                               files=location)
        else:
            response = self.controller.pull_package(package_name,
                                               force, draft=draft, user_slug=self.user_slug,
                                               label=label, current_account=self.current_account)
        return response

    def push_package(self, account, package, **kwargs):
        """
        Pushes the local package up to the hub, provided there are no conflicts.
        If a list of files/file paths is specified after the --files flag,
        then only those files are pushed up. It print conflicts files.
        --force causes remote files to be overwritten with no warning.
        """
        error_list = []
        pack = kwargs.get('pack', None)
        files = package.files
        package_name = package.package_name
        package_id = package.package_id
        force = package.force
        replace_from_hub_list = package.replace_from_hub_list
        if replace_from_hub_list:
            if files:
                result = self.controller.as_jptf(replace_from_hub_list)
            else:
                result = self.controller.as_partial_jptf(replace_from_hub_list, pack)
            response = self.controller.push_package(
                       package_name, force=force, user_slug=self.user_slug,
                       replace_from_hub_list=result, current_account=self.current_account)
        elif files:
            response = self.controller.push_package(package_name, force=force, user_slug=self.user_slug,
                                               files=files, current_account=self.current_account)
        else:
            try:
                response = self.controller.push_package(package_name, force=force, user_slug=self.user_slug, current_account=self.current_account)
            except BlendedException as exc:
                raise BlendedException(exc)
        if isinstance(response, tuple):
            response, error_list = response
            if error_list:
                for image_name in error_list:
                    print("Some error in uploading image %s.\n" % (image_name))
        return response

    def compare_package(self, account, package):
        """
        If any differences are found, conflicts/differences are printed listing all of the files and their locations,
        and the command exits.
        """
        files = package.files
        package_name = package.package_name
        package_id = package.package_id
        label = package.label
        controller = self.controller
        backend = self.backend
        if package_name:
            identifiers = package_name.split("/")
            if len(identifiers) > 1:
                if (self.current_account == identifiers[0]):
                    package_name = identifiers[1]
                else:
                    raise BlendedException('Account name \"%s\" is not Current account or valid account.' % identifiers[0])

        try:
            hub_package = controller.network.download_draft(self.current_account, package_name, as_hashes="1")
            hub_jptf, package_hash, canonical_type = controller._remove_root_from_jptf(hub_package)
            if controller.backend.directory_path.endswith('src'):
                package_slug_temp = os.path.join(controller.backend.directory_path, package_slug)
            else:
                package_slug_temp = os.path.join(controller.backend.directory_path, controller.backend.src, package_name)

            hub_package = controller.de_jptf(hub_jptf, as_hashes=True, package_slug=package_slug_temp)
            hub_package = controller.backend.get_class('intermediary')(
                                                       package_name, content=hub_package,
                                                       name=package_name, hash=package_hash, as_hashes=True)
        except BlendedException as exc:
            raise BlendedException(exc)
        try:
            package = controller.backend.get_package(package_name)
        except BlendedException as exc:
            raise BlendedException(exc)
        local_last_hash = backend.get_hash(package_name)
        response = controller.compare_package(hub_package, package, local_last_hash, "compare")
        return response

    def update_package(self, account, package):
        """
        It updates package with another package except hash_file/_package.json.
        Update package in local not on the hub.
        """
        package_name = package.package_name
        source_package = package.source_package
        label = package.label
        package_id = package.package_id
        force = package.force
        response = self.controller.update_package(package_name, source_package,
                                                  current_account=self.current_account,
                                                  label=label, force=force)
        return response

    def get_versions_list(self, account, package):
        """
        It provides list of all snapshot version of a package.
        --canonical flag used to get the canonical version of a package.
        """
        package_name = package.package_name
        canonical = package.canonical
        package_id = package.package_id
        response = self.controller.package_version(self.current_account, package_name, canonical=canonical)
        return response

    def package_snapshot(self, account, package, **kwargs):
        """
        Creates a new version based on the current state of the draft.
        """
        auto_share_packages = kwargs.get('auto_share_packages', [])
        purchase_packages = kwargs.get('purchase_packages', [])
        skip_validation = package.skip_validation
        package_name = package.package_name
        label = package.label
        package_id = package.package_id
        response = self.controller.package_snapshot(self.current_account,package_name,label=label,
                                                    auto_share_packages=auto_share_packages, purchase_packages=purchase_packages, 
                                                    skip_validation=skip_validation)
        return response

    def package_canonical(self, account, package):
        """
        Markes the specified version as the cannonical version.
        """
        package_name = package.package_name
        label = package.label
        package_id = package.package_id
        response = self.controller.package_canonical(self.current_account, package_name, label=label)
        return response

    def package_share(self, account, package, **kwargs):
        """
        Makes the package available privately to the specified account to download and clone.
        """
        auto_share_packages = kwargs.get('auto_share_packages', [])
        package_name = package.package_name
        email = account.email
        account_name = account.account_name
        package_id = package.package_id
        get = package.get
        if auto_share_packages:
            response = self.controller.package_share(
                       self.current_account, package_name,
                       account_name=account_name, email=email,
                       auto_share_packages=auto_share_packages)
        else:
            response = self.controller.package_share(self.current_account,
                                                     package_name,
                                                     account_name=account_name,
                                                     email=email,
                                                     get=get)
        return response

    def package_transfer(self, account, package,  **kwargs):
        """
        Moves all licensing rights for a package from the current account to the specified account.
        """
        auto_share_packages = kwargs.get('auto_share_packages', [])
        purchase_packages = kwargs.get('purchase_packages', [])
        package_name = package.package_name
        email = account.email
        account_name = account.account_name
        package_id = package.package_id
        if auto_share_packages or purchase_packages:
            response = self.controller.package_transfer(self.current_account,
                                                        package_name,
                                                        account_name=account_name,
                                                        email=email,
                                                        auto_share_packages=auto_share_packages,
                                                        purchase_packages=purchase_packages)
        else:
            response = self.controller.package_transfer(self.current_account,
                                                        package_name,
                                                        account_name=account_name,
                                                        email=email)
        return response

    def package_as_json(self, account, package):
        """
        It gives json of package. For now It work only for local package.
        """
        package_name = package.package_name
        package_id = package.package_id
        identifiers = package_name.split("/")
        if len(identifiers) > 1:
            if (self.current_account == identifiers[0]):
                package_name = identifiers[1]
            else:
                raise BlendedException('Account name \"%s\" is not Current account or valid account.' % identifiers[0])
        try:
            package = self.controller.backend.get_package(package_name)
        except BlendedException as exc:
            raise BlendedException(exc)
        return self.controller.as_jptf(package)

    def package_detail(self, account, package):
        """
        Prints the details of the package in a nice format, with less-like up-and-down behavior.
        --description causes only the description of the package.
        --licenses lists all the licenses for the package.
        """
        package_name = package.package_name
        package_id = package.package_id
        is_description = package.is_description
        is_licenses = package.is_licenses
        response = self.controller.package_detail(self.current_account, package_name)
        return response

    def package_publish(self, account, package, **kwargs):
        """
        publication of package.
        """
        publication = kwargs.get('publication', [])
        package_name = package.package_name
        package_id = package.package_id
        canonical = package.canonical
        validate = package.validate
        get_publish = package.get
        response = self.controller.package_publication(
                            self.current_account, package_name, publication,
                            canonical=canonical, validate=validate, get_publish=get_publish
                            )
        return response

    def package_validate(self, account, package):
        """
        Creates a new package.
        """
        package_name = package.package_name
        package_id = package.package_id
        label = package.label
        response = self.controller.package_validate(self.current_account,
                                                    package_name,
                                                    label=label)
        return response
        
    def account_email_verification(self, email):
        """
        """
        response = self.controller.account_email_verification(email)
        return response

    def get_title(self, account_name, package_name):
        """
        """
        response = self.controller.get_title(account_name, package_name)
        return response
    
    def package_revoke(self, account, package):
        """
        Creates a new package.
        """
        package_name = package.package_name
        account_name = account.account_name
        share = package.share
        transfer = package.transfer
        package_id = package.package_id
        email = account.email
        response = self.controller.package_revoke(self.current_account,
                                                  package_name,
                                                  account_name,
                                                  email=email,
                                                  share=share,
                                                  transfer=transfer)
        return response

    def package_reject(self, account, package):
        """
        Reject package access.
        """
        package_name = package.package_name
        account_name = account.account_name
        share = package.share
        transfer = package.transfer
        package_id = package.package_id
        
        response = self.controller.package_reject(self.current_account,
                                                  package_name,
                                                  account_name,
                                                  share=share,
                                                  transfer=transfer)
        
        return response

    def package_accept(self, account, package):
        """
        Creates a new package.
        """
        package_name = package.package_name
        account_name = account.account_name
        new_name = package.new_name
        package_id = package.package_id
        
        response = self.controller.package_accept(self.current_account,
                                                  package_name,
                                                  account_name,
                                                  new_name=new_name)
        return response
        
    def check_package(self, account_name, package_name):
        """
        check package existence.
        """
        self.controller.check_package(account_name, package_name)
        


# coding: utf-8

"""
    Swagger Blended Hub API Explorer

    A collection of Swagger documentation for the Blended Hub APIs.

    OpenAPI spec version: 1.0.0
    Contact: api@blended.co
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class AddPending(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, email=None, account_slug=None, access_type=None):
        """
        AddPending - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'email': 'str',
            'account_slug': 'str',
            'access_type': 'str'
        }

        self.attribute_map = {
            'email': 'email',
            'account_slug': 'account_slug',
            'access_type': 'access_type'
        }

        self._email = email
        self._account_slug = account_slug
        self._access_type = access_type

    @property
    def email(self):
        """
        Gets the email of this AddPending.
        email that needs to be invite to join accoun.

        :return: The email of this AddPending.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this AddPending.
        email that needs to be invite to join accoun.

        :param email: The email of this AddPending.
        :type: str
        """

        self._email = email

    @property
    def account_slug(self):
        """
        Gets the account_slug of this AddPending.
        account slug of user that needs to be invite to join accoun

        :return: The account_slug of this AddPending.
        :rtype: str
        """
        return self._account_slug

    @account_slug.setter
    def account_slug(self, account_slug):
        """
        Sets the account_slug of this AddPending.
        account slug of user that needs to be invite to join accoun

        :param account_slug: The account_slug of this AddPending.
        :type: str
        """

        self._account_slug = account_slug

    @property
    def access_type(self):
        """
        Gets the access_type of this AddPending.
        Account permission for the invitee user.

        :return: The access_type of this AddPending.
        :rtype: str
        """
        return self._access_type

    @access_type.setter
    def access_type(self, access_type):
        """
        Sets the access_type of this AddPending.
        Account permission for the invitee user.

        :param access_type: The access_type of this AddPending.
        :type: str
        """

        self._access_type = access_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from setuptools import setup, find_packages
import pathlib

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

VERSION = '0.0.2'
DESCRIPTION = 'A cross-platform design theme framework.'


# Setting up
setup(
    name="blendedux",
    version=VERSION,
    author="Himanshu",
    author_email="<hbhadu@cognam.com>",
    description=DESCRIPTION,
    long_description=README,
    long_description_content_type="text/markdown",
    license="MIT",
    packages=find_packages(),
    install_requires=[
        'certifi==2022.5.18.1',
        'click==8.1.3',
        'colorama==0.4.4',
        'Flask==0.11.1',
        'itsdangerous==2.0.1',
        'Jinja2==2.8',
        'MarkupSafe==2.0.1',
        'Pillow==8.0.1',
        'python-dateutil==2.8.2',
        'six==1.16.0',
        'urllib3==1.26.9',
        'Werkzeug==2.0.3',
        'blendedUx-Lang==1.0.0'
    ]
)


# coding: utf-8

"""
    Swagger Blended Hub API Explorer

    A collection of Swagger documentation for the Blended Hub APIs.

    OpenAPI spec version: 1.0.0
    Contact: api@blended.co
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class CreateVersion(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, label=None, hash_as_token=None, auto_share_packages=None, purchase_packages=None, skip_validation=None):
        """
        CreateVersion - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'label': 'str',
            'hash_as_token': 'str',
            'auto_share_packages': 'list[str]',
            'purchase_packages': 'list[str]',
            'skip_validation': 'bool'
        }

        self.attribute_map = {
            'label': 'label',
            'hash_as_token': 'hash_as_token',
            'auto_share_packages': 'auto_share_packages',
            'purchase_packages': 'purchase_packages',
            'skip_validation': 'skip_validation'
        }

        self._label = label
        self._hash_as_token = hash_as_token
        self._auto_share_packages = auto_share_packages
        self._purchase_packages = purchase_packages
        self._skip_validation = skip_validation

    @property
    def label(self):
        """
        Gets the label of this CreateVersion.
        version label.

        :return: The label of this CreateVersion.
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """
        Sets the label of this CreateVersion.
        version label.

        :param label: The label of this CreateVersion.
        :type: str
        """

        self._label = label

    @property
    def hash_as_token(self):
        """
        Gets the hash_as_token of this CreateVersion.
        use as token for push

        :return: The hash_as_token of this CreateVersion.
        :rtype: str
        """
        return self._hash_as_token

    @hash_as_token.setter
    def hash_as_token(self, hash_as_token):
        """
        Sets the hash_as_token of this CreateVersion.
        use as token for push

        :param hash_as_token: The hash_as_token of this CreateVersion.
        :type: str
        """

        self._hash_as_token = hash_as_token

    @property
    def auto_share_packages(self):
        """
        Gets the auto_share_packages of this CreateVersion.
        list of dependency packages which needs to shared.

        :return: The auto_share_packages of this CreateVersion.
        :rtype: list[str]
        """
        return self._auto_share_packages

    @auto_share_packages.setter
    def auto_share_packages(self, auto_share_packages):
        """
        Sets the auto_share_packages of this CreateVersion.
        list of dependency packages which needs to shared.

        :param auto_share_packages: The auto_share_packages of this CreateVersion.
        :type: list[str]
        """

        self._auto_share_packages = auto_share_packages

    @property
    def purchase_packages(self):
        """
        Gets the purchase_packages of this CreateVersion.
        list of dependency packages which needs to purchases.

        :return: The purchase_packages of this CreateVersion.
        :rtype: list[str]
        """
        return self._purchase_packages

    @purchase_packages.setter
    def purchase_packages(self, purchase_packages):
        """
        Sets the purchase_packages of this CreateVersion.
        list of dependency packages which needs to purchases.

        :param purchase_packages: The purchase_packages of this CreateVersion.
        :type: list[str]
        """

        self._purchase_packages = purchase_packages

    @property
    def skip_validation(self):
        """
        Gets the skip_validation of this CreateVersion.
        Flag to specify whether to run validators or skip

        :return: The skip_validation of this CreateVersion.
        :rtype: bool
        """
        return self._skip_validation

    @skip_validation.setter
    def skip_validation(self, skip_validation):
        """
        Sets the skip_validation of this CreateVersion.
        Flag to specify whether to run validators or skip

        :param skip_validation: The skip_validation of this CreateVersion.
        :type: bool
        """

        self._skip_validation = skip_validation

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



class BlendedException(Exception):
    """
    Custom Exception for blendedcli,raise when something specific goes wrong.
    """
    pass


class AccountActivationException(Exception):
    """
    Custom Exception for inactive blended accounts if user try to logging it.
    """
    pass


class PackageNameExistsException(Exception):
    """
    Custom Exception raised if package name already exists in the account.
    """
    pass




from __future__ import absolute_import,  unicode_literals
import os
import sys
import zlib
import base64
import hashlib
import json
import configparser
from PIL import Image
import shutil
from shutil import copyfile
import stat
try:
    from urllib import urlretrieve, urlopen
    from urllib2 import urlopen
except ImportError:
    from urllib.request import urlretrieve, urlopen

from blendedUx.blended_flask.blended_hostlib.exceptions import BlendedException

from .settings import SRC, LIB, CANONICAL_TXT, HASH_TXT, PROJECT_JSON, \
                      INDEX_JSON, USER_RC, CACHE_DICT, DEFAULT_ALIAS as alias, \
                      BLENDED_ACCOUNT, BLENDED_BASIC
from .settings import ALLOWED_IMAGE_TYPES, PACKAGE_LIST_RC as package_list_rc_file
from .intermediary import IntermediaryNode, Directory, \
    TextFile, BinaryFile, JSONFile

user_rc_file = USER_RC


def create_project_json(package_path, data=None):
    """
    """
    if not data:
        data = {}
    with open(package_path, 'w') as json_file:
        json.dump(data, json_file, indent=4)


def update_project_json(package_path, package_details):
    """
    """
    json_file = open(package_path)
    json_data = json_file.read()
    json_file.close()
    try:
        data = json.loads(json_data)
    except ValueError:
        raise BlendedException("invalid data in _package.json")
    except Exception:
        raise BlendedException(exc.args[0])
    package_title_and_type_check(data, package_details)
    load_dependency(data, package_details)
    data.update(package_details)
    create_project_json(package_path, data)


def package_title_and_type_check(data, package_details):
    """
    data reads from backend.
    package_details come from cli commands.
    """
    try:
        pack_type = package_details['type']
    except:
        try:
            if not data['type']:
                raise BlendedException('You need to provide "Type" of package.')
        except:
            raise BlendedException('You need to provide "Type" of package.')

    try:
        title = package_details['title']
    except:
        try:
            if not data['title']:
                raise BlendedException('You need to provide "title" of package.')
        except:
            raise BlendedException('You need to provide "title" of package.')


def load_dependency(data, package_details):
    """
    """
    try:
        dependency = data['dependencies']
        if dependency:
            pack_list = dependency_check(dependency)
            item = {data['name']: data['version']}
            if item in pack_list:
                raise BlendedException("There should not be a circular dependency in package \"%s\"." % (item))
    except KeyError:
        pass
    except BlendedException as exc:
        raise BlendedException(exc.args[0])
    except Exception:
        raise BlendedException("invalid data in _package.json")


def dependency_check(dependency_list, package_list1=[]):
    """
    load the dependency based on the alias name of the theme and the uuid
    """
    alias_dict = []
    version_list = []
    package_list = []
    for dependency in dependency_list:
        theme_slug = dependency.get('name')
        dep_alias = dependency.get('alias')
        version = dependency.get('version')
        # dep_uuid = dependency.get('uuid')
        # account = dependency.get('account')
        dependencies = dependency.get('dependencies')
        if not theme_slug:
            raise BlendedException({'msg': 'Error: "name" is not defined with dependency package.', 'status_code':7777})
        if not dep_alias:
            raise BlendedException({'msg': 'Error: "alias" is not defined with dependency package "%s".' % theme_slug, 'status_code':7777})
        if not version:
            raise BlendedException({'msg': 'Error: "version" is not defined with dependency package "%s".' % theme_slug, 'status_code':7777})
        if not (version and dep_alias and theme_slug):
            raise BlendedException("Version, alias, and name are required for defining dependency.")
        package_slug = theme_slug.rsplit("/")[1]
        if dep_alias in alias_dict:
            raise BlendedException({'msg': 'Error: Duplicate entry found of "alias" with dependency package "%s".' % theme_slug, 'status_code':7777})
        if (version in version_list) and (package_slug in package_list):
            raise BlendedException({'msg': "You cannot make same version dependency multiple time: "
                                   "version \"%s\" of package \"%s\" " % (version, package_slug), 'status_code':7777})
        item = {theme_slug: version}
        if dependencies:
            if item in dependency_check(dependencies, package_list1=package_list1):
                raise BlendedException({'msg': "There should not be a circular dependency in package \"%s\"." % (item), 'status_code':7777})
        alias_dict.append(dep_alias)
        version_list.append(version)
        package_list.append(package_slug)
        package_list1.append(item)
    return package_list1


class FileSystemBackend(object):
    """
    backend class for filesystem
    """
    def __init__(self, directory_path=None, blended_dir=None,
                 current_account=None, blended_directory_path=None,
                 last_login=None):
        self.directory_path = directory_path
        self.src_or_lib = None
        self.last_login = last_login
        self.blended_dir = blended_dir
        self.current_account = current_account
        self.blended_directory_path = blended_directory_path

    def validate_package_json(self, json_obj):
        title = json_obj.get('title', {})
        name = json_obj.get('name', {})
        package_type = json_obj.get('type', {})
        reuired_fields = []
        if not title:
            reuired_fields.append('"title"')
        if not name:
            reuired_fields.append('"name"')
        if not package_type:
            reuired_fields.append('"type"')
        if reuired_fields:
            error_message = ', '.join(reuired_fields)
            raise BlendedException({'message':'%s field(s) are missing in package.json. "name", "title", '
                                    '"type" are required fields for package.' % (error_message),
                                    'status_code': 9003})
        return

    def dependency_version_check(self, dependency_list, version_list=[], action=None):
        """
        load the dependency based on the alias name of the theme and the uuid
        #['draft', 'viewlayout', 'layout', 'theme', 'canonical']
        """
        for dependency in dependency_list:
            version = dependency.get('version')
            dependencies = dependency.get('dependencies')
            if version.lower() in ['draft', 'canonical']:
                if action == 'snapshot' or action == 'transfer':
                    version_list.append(dependency.get('name'))
                else:
                    version_list.append({dependency.get('name'): version})
            if dependencies:
                self.dependency_version_check(dependencies, version_list=version_list, action=action)
        return version_list

    def update_src_copy_dst(self, response, source_package_name, package_slug, source_package, account_slug, version=None):
        """
        """
        for item in response:
            if version:
                src = item.location
                dst = item.location.replace(os.path.join('lib', source_package, version), os.path.join('src', package_slug))
            else:
                src = item.location
                dst = item.location.replace(os.path.join('src', source_package_name), os.path.join('src', package_slug))
                # dst = item.location.replace(source_package_name, package_slug)
            try:
                if os.path.isdir(src):
                    shutil.copytree(src, dst)
                else:
                    shutil.copy2(src, dst)
            except Exception as e:
                raise Exception(e)
        return package_slug

    def get_class(self, classname):
        """
        """
        classes = {"intermediary": IntermediaryNode,
                   "Directory": Directory,
                   "JSONFile": JSONFile,
                   "TextFile": TextFile,
                   "BinaryFile": BinaryFile}
        return classes[classname]

    def set_canonical(self, account, package_slug, canonical_detail=None, clone_flag=None, version=None):
        """
        """
        blended_dir = self.get_blended_directory_path()
        if not blended_dir.endswith(self.current_account):
            lib_dir = os.path.join(blended_dir, self.current_account, LIB, account, package_slug)
        elif clone_flag:
            lib_dir = account
        else:
            lib_dir = os.path.join(blended_dir, account, LIB, account, package_slug)
        if not os.path.exists(lib_dir):
            os.makedirs(lib_dir)
        if canonical_detail or version:
            if version:
                label = version
            else:
                label = canonical_detail.to_dict()['label']
            canonical_file = open(lib_dir + os.sep + CANONICAL_TXT, "w")
            canonical_file.write("canonical = '%s'" % label)
            canonical_file.close()
            version_dir = os.path.join(lib_dir, label)
            if not os.path.exists(version_dir):
                return True
            return False

    def set_hash(self, dir_path, _hash=None):
        """
        """
        if dir_path.__class__.__name__ == 'Directory':
            current_account = self.get_current_account()
            src_dir = os.path.join(current_account, SRC)
            dir_path = os.path.join(self.directory_path, dir_path.name)
        if _hash:
            hash_file = open(dir_path + os.sep + HASH_TXT, "w")
            hash_file.write("hash = '%s'" % _hash)
            hash_file.close()

    def get_canonical(self, account, package_slug, **kwargs):
        """
        """
        current_account = kwargs.get('current_account', None)
        blended_dir = self.get_blended_directory_path()
        if current_account:
            lib_dir = os.path.join(blended_dir, current_account, LIB, account, package_slug, CANONICAL_TXT)
        else:
            lib_dir = os.path.join(blended_dir, account, LIB, account, package_slug, CANONICAL_TXT)

        if os.path.exists(lib_dir):
            canonical_file = open(lib_dir, "r")
            response = canonical_file.read().rsplit(" = ")[1]
            canonical_file.close()
            return response.strip("'")
        else:
            return None

    def create_account(self):
        if not os.path.exists(self.directory_path):
            os.makedirs(self.directory_path)

    def account_login(self):
        """
        method that will in filesystem for the sessionkey to
        login into the account.
        """
        pass

    def get_title(self,  account_name, slug):
        """
        """
        if not self.directory_path.endswith('src'):
            self.set_src
        current_dir = self.directory_path
        package_name = str(slug)
        package_directory = os.path.join(current_dir, package_name)
        lst = []
        try:
            lst = os.listdir(current_dir)
        except OSError:
            pass
        if package_name not in lst:
            raise BlendedException({'status_code': 5008, 'message': 'Package does not exist.'})
        package_path = os.path.join(current_dir, package_name, PROJECT_JSON)
        if not os.path.isfile(package_path):
            raise BlendedException({'status_code': 7000, 'message': 'Package does not have _package.json.'})
        json_file = open(package_path)
        json_data = json_file.read()
        json_file.close()
        try:
            data = json.loads(json_data)
        except ValueError:
            raise BlendedException({'status_code': 7000, 'message':'invalid data in "_package.json".'})
        except Exception:
            raise BlendedException(exc.args[0])
        try:
            title = data['title']
        except:
            raise BlendedException({'status_code': 7000, 'message': 'Package does not have title.'})
        return title

    def copy_validate_folder(self, account_name, package_name):
        """
        copy validator folder in created package.
        """
        # validate_folder = os.path.join(os.getcwd(), 'validation')
        current_account = self.get_current_account()
        label = self.get_canonical(BLENDED_ACCOUNT, BLENDED_BASIC, current_account=current_account)
        lib_path = os.path.dirname(self.directory_path)
        validate_folder = os.path.join(lib_path, LIB, BLENDED_ACCOUNT, BLENDED_BASIC, label, 'validation')
        package_path = os.path.join(self.directory_path, package_name, 'validation')
        if os.path.exists(validate_folder):
            try:
                shutil.copytree(validate_folder, package_path)
            except:
                pass

    def copy_validate_package(self, account_name, package_name, blended_package):
        """
        copy validator package in created package.
        """
        current_account = self.get_current_account()
        label = self.get_canonical(BLENDED_ACCOUNT, blended_package, current_account=current_account)
        lib_path = os.path.dirname(self.directory_path)
        validate_folder = os.path.join(lib_path, LIB, BLENDED_ACCOUNT, blended_package, label)
        package_path = os.path.join(self.directory_path, package_name)
        if os.path.exists(validate_folder):
            try:
                shutil.copytree(validate_folder, package_path)
            except:
                pass

    def create_package(self, account_name, package_name, package_type, description, package_title, primary_category, secondary_category=None):
        """
        """
        current_dir = self.directory_path
        package_name = str(package_name)
        package_directory = os.path.join(current_dir, package_name)
        # current_account = self.get_current_account()
        active_account = self.last_login
        if not active_account:
            active_account = account_name
        if not description:
            description = ""
        pack_details = self.read_package_json(package_name)
        name = '%s/%s' % (account_name, package_name)
        try:
            lst = os.listdir(current_dir)
        except OSError:
            os.makedirs(current_dir)
            lst = os.listdir(current_dir)
        if package_name not in lst:
            os.makedirs(package_directory)
        else:
            try:
                assert not os.path.isfile(package_directory)
            except AssertionError:
                raise BlendedException('%s can not be a file.' % (package_name,))

        package_details = {'name': name.lower(),
                           'slug': package_name.lower(),
                           'user': active_account.lower(),
                           'version': 'draft',
                           'account': account_name.lower(),
                           }
        if package_type:
            package_details.update({'type': package_type.lower()})
        if package_title:
            package_details.update({'title': package_title})
        if primary_category:
            package_details.update({'primary_category': primary_category})
        if secondary_category:
            package_details.update({'secondary_category': secondary_category})
        if pack_details and account_name == 'anonymous':
            try:
                if pack_details['name'] == name:
                    raise BlendedException("Package already present", 5011)
                else:
                    pass
            except KeyError:
                pass

        package_path = os.path.join(current_dir, package_name, PROJECT_JSON)
        if os.path.isfile(package_path):
            try:
                update_project_json(package_path, package_details)
            except BlendedException as exc:
                raise BlendedException(exc)
        else:
            create_project_json(package_path)
            try:
                package_details['description'] = description
                package_details['dependencies'] = []
                update_project_json(package_path, package_details)
            except BlendedException as exc:
                raise BlendedException(exc)

    def update_package_anonymous_to_login_user(self, package_name, current_dir, current_account):
        """
        """
        package_path = os.path.join(current_dir, package_name, '_package.json')
        package_details = self.read_package_json(package_name)
        name = '%s/%s' % (current_account, package_name)
        user = current_account.lower()
        account = current_account.lower()
        package_details.update({'name': name, 'user': user, 'account': account})
        if os.path.isfile(package_path):
            try:
                update_project_json(package_path, package_details)
            except BlendedException as exc:
                raise BlendedException(exc)
        return

    def read_package_json(self, package_name):
        """
        """
        current_dir = self.directory_path
        package_path = os.path.join(current_dir, package_name, PROJECT_JSON)
        if os.path.exists(package_path):
            json_file = open(package_path)
            json_data = json_file.read()
            json_file.close()
            try:
                data = json.loads(json_data)
            except ValueError:
                raise BlendedException("invalid data in _package.json")
            return data
        else:
            return {}

    def update_project_dot_json(self, package_path, package_details):
        """
        :param package_path:
        :param package_details:
        :return:
        """
        update_project_json(package_path, package_details)

    def create_blended_rc(self, pk, package_name, package_type):
        """
        """
        current_dir = self.directory_path
        blended_rc_path = os.path.join(current_dir, package_name, BLENDED_RC)
        config = configparser.ConfigParser()
        dot_blended_dir = blended_rc_path.rsplit(os.sep, 1)[0]
        if not os.path.isdir(dot_blended_dir):
            os.makedirs(dot_blended_dir)
        try:
            config.add_section('Package')
            config.set('Package', 'pk', str(pk))
            config.set('Package', 'name', str(package_name))
            config.set('Package', 'type', str(package_type))
        except (configparser.NoSectionError, configparser.NoOptionError, OSError, IOError) as exc:
            raise BlendedException(exc)

        with open(blended_rc_path, 'w') as blendedrc_file:
            config.write(blendedrc_file)

    def get_hash(self, package_name, **kwargs):
        """
        :param kwargs:
        :return:
        """
        current_dir = self.directory_path
        blended_rc_path = os.path.join(current_dir, package_name, HASH_TXT)
        if os.path.exists(blended_rc_path):
            hash_file = open(blended_rc_path, "r")
            response = hash_file.read().rsplit(" = ")[1].strip("'")
            hash_file.close()
            return response
        else:
            return ''

    def update_blendedrc(self, package_name, **kwargs):
        """
        """
        draft_id = kwargs.get('draft_id')
        version = kwargs.get('label')
        version_pk = kwargs.get('version_pk')
        description = kwargs.get('description')
        pk = kwargs.get('pk')
        package_type = kwargs.get('package_type')
        last_hash = kwargs.get('last_hash')
        slug = kwargs.get('slug')
        current_dir = self.directory_path
        blended_rc_path = os.path.join(current_dir, package_name, BLENDED_RC)
        config = configparser.ConfigParser()
        config.read(blended_rc_path)

        if slug:
            try:
                config.set('Package', 'slug', str(slug))
                config.set('Package', 'name', str(package_name))
            except (configparser.NoSectionError, configparser.NoOptionError, OSError, IOError) as exc:
                config.add_section('Package')
                config.set('Package', 'slug', str(slug))
                config.set('Package', 'name', str(package_name))

        if pk:
            try:
                config.set('Package', 'pk', str(pk))
                config.set('Package', 'name', str(package_name))
            except (configparser.NoSectionError, configparser.NoOptionError, OSError, IOError) as exc:
                config.add_section('Package')
                config.set('Package', 'pk', str(pk))
                config.set('Package', 'name', str(package_name))

        if package_type:
            try:
                config.set('Package', 'type', str(package_type))
                config.set('Package', 'name', str(package_name))
            except (configparser.NoSectionError, configparser.NoOptionError, OSError, IOError) as exc:
                config.add_section('Package')
                config.set('Package', 'type', str(package_type))
                config.set('Package', 'name', str(package_name))

        if description:
            try:
                config.set('Package', 'description', str(description))
                config.set('Package', 'name', str(package_name))
            except (configparser.NoSectionError, configparser.NoOptionError, OSError, IOError) as exc:
                config.add_section('Package')
                config.set('Package', 'description', str(description))
                config.set('Package', 'name', str(package_name))

        if last_hash:
            try:
                config.set('Package', 'last_hash', str(description))
                config.set('Package', 'name', str(package_name))
            except (configparser.NoSectionError, configparser.NoOptionError, OSError, IOError) as exc:
                config.add_section('Package')
                config.set('Package', 'last_hash', str(description))
                config.set('Package', 'name', str(package_name))

        if draft_id:
            try:
                config.set('Draft', 'draft_pk', str(draft_id))
            except (configparser.NoSectionError, configparser.NoOptionError, OSError, IOError) as exc:
                config.add_section('Draft')
                config.set('Draft', 'draft_pk', str(draft_id))

        if version:
            try:
                config.set('Version', str(version), str(version_pk))
            except (configparser.NoSectionError, configparser.NoOptionError, OSError, IOError) as exc:
                config.add_section('Version')
                config.set('Version', str(version), str(version_pk))

        with open(blended_rc_path, 'w') as blendedrc_file:
            config.write(blendedrc_file)

    def get_blended_directory_path(self):
        """
        :return:
        """
        return self.blended_directory_path

    def get_draft_id(self, package_name):
        """
        """
        current_dir = self.directory_path
        blended_rc_path = os.path.join(current_dir, package_name, BLENDED_RC)
        config = configparser.ConfigParser()
        try:
            config.read(blended_rc_path)
            draft_id = config.get('Draft', 'draft_pk')
        except (configparser.NoSectionError, configparser.NoOptionError, OSError, IOError) as exc:
            draft_id = None

        return draft_id

    def get_version_id(self, package_name, label):
        """
        """
        current_dir = self.directory_path
        blended_rc_path = os.path.join(current_dir, package_name, BLENDED_RC)
        config = configparser.ConfigParser()
        try:
            config.read(blended_rc_path)
            version_id = config.get('Version', label)
        except (configparser.NoSectionError, configparser.NoOptionError, OSError, IOError) as exc:
            raise BlendedException("There is some issue with configuration of package")
        return version_id

    def get_package_acquisition(self, package_name, license_name, new_name):
        """
        method look for the package in the filesystem
        """
        pass

    def package_push(self):
        """
        """
        pass

    def save_local(self, package_name, intermediary_object, **kwargs):
        """
        """
        files = kwargs.get('files')
        blended_dir = self.get_blended_directory_path()
        is_draft = kwargs.get('draft')
        is_owner = kwargs.get('owner', True)
        dependency = kwargs.get('dependency', False)
        version = kwargs.get('version', False)
        current_account = self.get_current_account()
        src_dir = os.path.join(blended_dir, current_account, SRC)
        lib_dir = os.path.join(blended_dir, current_account, LIB)
        identifiers = package_name.split("/")
        if len(identifiers) > 1:
            account = identifiers[0]
            package_slug = identifiers[1]
        else:
            try:
                account = self.get_current_account()
            except BlendedException as exc:
                raise BlendedException(exc)
            package_slug = identifiers[0]
        if files:
            package_name = os.path.join(self.directory_path, src_dir, package_slug)
        elif is_draft:
            package_name = os.path.join(self.directory_path, src_dir, package_slug)
        elif (not is_owner) or (dependency):
            package_name = os.path.join(self.directory_path, lib_dir, package_name, version)
        elif version:
            package_name = os.path.join(self.directory_path, lib_dir, package_name, version)
        elif self.directory_path.endswith('src'):
            package_name = os.path.join(self.directory_path, package_slug)
        else:
            # version label needs to be implemented here
            package_name = os.path.join(self.directory_path, SRC, package_slug)
        # try:
        if not files:
            try:
                shutil.rmtree(package_name)
            except:
                pass
        temp_path = os.path.join(package_name, '.temp')
        try:
            media_for_download = dict()
            self.intermediary_to_filesystem(temp_path, intermediary_object.content,
                                            media_for_download=media_for_download)
            try:
                self.download_media_concurrent_or_sequential(media_for_download=media_for_download)
            except Exception as e:
                print("Something went wrong while downloading the package media files.")
                sys.exit(1)
        except Exception as exc:
            if os.path.exists(temp_path):
                try:
                    shutil.rmtree(temp_path)
                except OSError as exc:
                    # os.system("taskkill /im explorer.exe")
                    try:
                        shutil.rmtree(temp_path)
                    except:
                        pass
            if not files:
                try:
                    shutil.rmtree(package_name)
                except OSError as exc:
                    try:
                        shutil.rmtree(package_name)
                    except:
                        pass
            raise BlendedException('Unable to download package due to Network failure. '
                                   'Please check your network connection and try again.')
        else:
            self.copy_temp_dir_to_original_package(temp_path, package_name)
            shutil.rmtree(temp_path)
        try:
            if files:
                intermediary_object = self.get_package(intermediary_object.name)
        except BlendedException as exc:
            raise BlendedException(exc)
        else:
            self.set_hash(package_name, intermediary_object.hash)
        return True
        # except BlendedException:
        #    raise BlendedException('Some file may not saved in the package')

    def copy_temp_dir_to_original_package(self, temp_path, package_name):
        """
        """
        for temp_dir in os.listdir(temp_path):
            temp_dirs = os.path.join(temp_path, temp_dir)
            package_copy_path = os.path.join(package_name, temp_dir)
            if not os.path.exists(package_copy_path):
                if os.path.isdir(temp_dirs):
                    shutil.copytree(temp_dirs, package_copy_path)
                else:
                    shutil.copy2(temp_dirs, package_copy_path)
            if os.path.isdir(temp_dirs):
                self.copy_temp_dir_to_original_package(temp_dirs, package_copy_path)
            else:
                shutil.copy2(temp_dirs, package_copy_path)

    def package_list(self, packages_dict):
        """
        """
        directory_path = self.directory_path
        # if not os.path.exists(directory_path):
        # os.makedirs(directory_path)
        path = os.path.join(directory_path, package_list_rc_file)
        config = configparser.ConfigParser()
        config.add_section('Packages')
        for k, v in packages_dict.items():
            config.set('Packages', str(k), str(v))
        with open(path, 'w') as config_file:
            config.write(config_file)

    def read_package_pk(self, package_name):
        """
        """
        config = configparser.ConfigParser()
        working_dir = self.directory_path
        path = os.path.join(working_dir, package_list_rc_file)
        try:
            config.read(path)
            package_pk = config.get('Packages', package_name)
        except (configparser.NoSectionError, configparser.NoOptionError, OSError, IOError):
            raise BlendedException()
        return int(package_pk)

    def get_current_account(self):
        """
        :return:
        """
        return self.current_account

    def create_extended_package(self, package_name, package, new_name, **kwargs):
        """
        :param package_name:
        :param description:
        :return:
        """
        description = kwargs.get('description', "")
        account_name = kwargs.get('account')
        label = kwargs.get('label')
        package_type = kwargs.get('package_type')
        package_title = kwargs.get('package_title')
        current_account = self.get_current_account()
        underscore_index_json = {}
        for item in package.content:
            key = item.name
            # if key == DOT_BLENDED:
            #     continue
            if (key == INDEX_JSON):
                try:
                    index_file_keys = list(item.content.keys())
                except AttributeError:
                    index_file_keys = list(json.loads(item.content).keys())

                for index_key in index_file_keys:
                    data = {"$ref": "@%s/%s" % (alias, index_key)}
                    underscore_index_json[index_key] = data
            elif (key != PROJECT_JSON):
                data = {"$ref": "@%s/%s" % (alias, key)}
                underscore_index_json[key] = data
            if (key == PROJECT_JSON):
                pack_json_content = json.loads(item.content)
                if not label:
                    label = pack_json_content['version']
        package_path = os.path.join(self.directory_path, new_name)

        if not os.path.exists(package_path):
            os.makedirs(package_path)

        underscore_index_dot_json_path = os.path.join(package_path, INDEX_JSON)

        with open(underscore_index_dot_json_path, 'w') as underscoreindexfile:
            json.dump(underscore_index_json, underscoreindexfile, indent=4)
        # commented code need not be in  dependency
        # dependencies_for_extend = pack_json_content.get('dependencies', [])
        underscore_project_json = {
                        'name': '%s/%s' % (current_account, new_name),
                        'description': description,
                        'version': 'draft',
                        'type': package_type,
                        'title': package_title,
                        'dependencies': [{
                                          'name': '%s/%s' % (account_name, package_name),
                                          'alias': 'parent',
                                          # 'description': pack_json_content['description'],
                                          'type': pack_json_content['type'],
                                          # 'dependencies': dependencies_for_extend,
                                          'account': account_name,
                                          'version': label
                         }]
        }
        underscore_project_dot_json_path = os.path.join(package_path, PROJECT_JSON)
        with open(underscore_project_dot_json_path, 'w') as underscoreprojectfile:
            json.dump(underscore_project_json, underscoreprojectfile, indent=4)

    def packages_in_src(self):
        """
        :return:
        """
        path = os.path.join(self.directory_path, SRC)
        if os.path.exists(path):
            return os.listdir(path)
        return []

    def packages_in_lib(self, account):
        """
        :return:
        """
        path = os.path.join(self.directory_path, LIB)
        if os.path.exists(path):
            accounts = os.listdir(path)
            if account in accounts:
                return os.listdir(os.path.join(path, account))
            return []
        return []

    @property
    def set_src(self):
        self.directory_path = os.path.join(self.directory_path, SRC)

    @property
    def src(self):
        return SRC

    @property
    def lib(self):
        return LIB

    def set_lib(self, account):
        self.directory_path = os.path.join(self.directory_path, LIB, account)

    def read_package_name(self, package_id):
        """
        """
        config = configparser.ConfigParser()
        working_dir = self.directory_path
        path = os.path.join(working_dir, package_list_rc_file)
        package_id = str(package_id)
        try:
            config.read(path)
            packages = dict(config._sections.get('Packages'))
            for key, value in packages.items():
                if value == package_id:
                    package_name = key
        except (configparser.NoSectionError, configparser.NoOptionError, OSError, IOError):
            raise BlendedException()
        return package_name

    def check_lib_or_src(self, dir_path, dependency=False, version=None, src_check=True, lib_check=True):
        """
        :param dir_path:
        :return:
        """
        identifiers = dir_path.split("/")
        if len(identifiers) > 1:
            account = identifiers[0]
            package_slug = identifiers[1]
        else:
            try:
                account = self.get_current_account()
            except BlendedException as exc:
                raise BlendedException(exc)
            package_slug = identifiers[0]
        if not self.directory_path.endswith(SRC):
            src_dir = os.path.join(self.directory_path, SRC)
        else:
            src_dir = self.directory_path
        lib_dir = os.path.join(self.directory_path, LIB)
        if (os.path.exists(src_dir)) and (package_slug in os.listdir(src_dir)) and src_check:
            self.directory_path = src_dir
        elif version and lib_check:
            version_path = os.path.join(lib_dir, account, package_slug, version)
            if (os.path.exists(lib_dir)) and (os.path.exists(version_path)):
                self.directory_path = lib_dir
            elif (dependency) and (os.path.exists(lib_dir)) and (os.path.exists(version_path)):
                self.directory_path = lib_dir
        elif (os.path.exists(lib_dir)) and (package_slug in self.packages_in_lib(account)) and lib_check:
            self.directory_path = lib_dir
        elif (dependency) and (os.path.exists(lib_dir)) and (package_slug in self.packages_in_lib(account)) and lib_check:
            self.directory_path = lib_dir
        else:
            raise OSError('First, try with a proper fully qualified name. If \"%s\" is still not found '
                          'in the filesystem, please download or install it first.' % (dir_path))

    def get_package(self, dir_path, theme_path=None, entry=True, dependency=False, version=None, action=None):
        """
        """
        intermediary_cache_name = None
        try:
            if entry:
                if version and version.lower() != 'draft':
                    self.check_lib_or_src(dir_path, dependency=dependency, version=version, src_check=False)
                else:
                    self.check_lib_or_src(dir_path, dependency=dependency, version=version, lib_check=False)

                if self.directory_path.endswith(SRC):
                    identifiers = dir_path.split("/")
                    if len(identifiers) > 1:
                        account = identifiers[0]
                        dir_path = identifiers[1]
                    else:
                        dir_path = identifiers[0]
                elif self.directory_path.endswith(LIB) and action!='pull':
                    identifiers = dir_path.split("/")
                    if not version:
                        current_account = self.get_current_account()
                        version = self.get_canonical(identifiers[0],  identifiers[1], current_account=current_account)

                    if version:
                        intermediary_cache_name = os.path.join(dir_path, version)
                        if CACHE_DICT.get(intermediary_cache_name, None):
                            return CACHE_DICT[intermediary_cache_name]
                        dir_path = os.path.join(dir_path, version)
                else:
                    self.directory_path = os.path.join(self.blended_directory_path, self.current_account)
                    raise OSError()

            dir_path = os.path.join(self.directory_path, dir_path)
            if(not theme_path):
                theme_path = dir_path
            intermediary_object = Directory(dir_path)
            path_validate_errors = intermediary_object.path_validate_errors
            if path_validate_errors and action=='push':
                raise BlendedException({'msg' : path_validate_errors, 'status_code': 5011})
            if intermediary_cache_name:
                CACHE_DICT[intermediary_cache_name] = intermediary_object
            return intermediary_object
        except BlendedException as exc:
            raise BlendedException(exc.args[0])
        except OSError as exc:
            raise OSError(exc)

    def intermediary_to_filesystem(self, package_name, intermediary_object, media_for_download=None):
        """
        """
        package_path = package_name
        if not os.path.isdir(package_path):
            os.makedirs(package_path)
        for data in intermediary_object:
            key = data.name
            value = data.content
            directory_path = os.path.join(package_path, key)
            keys = key.rsplit('.', 1)
            if(len(keys) > 1):
                with_extension = True
                extension = ('.%s' % (keys[1]))
            else:
                with_extension = False
            if isinstance(data, Directory):
                # directory_path = os.path.join(package_path, data.location)
                self.intermediary_to_filesystem(directory_path, data.content,
                                                media_for_download=media_for_download)
            directory_path = os.path.join(package_path, data.name)
            if isinstance(data, BinaryFile):
                if (with_extension and extension.lower() in ALLOWED_IMAGE_TYPES):
                    # urlretrieve(value, directory_path)
                    if isinstance(media_for_download, dict) and (directory_path not in media_for_download):
                        media_for_download[directory_path] = value
                    else:
                        image_response = urlopen(value, timeout=40)
                        image_obj = image_response.read()
                        with open(directory_path, 'wb') as imagefile:
                            imagefile.write(image_obj)
            if isinstance(data, JSONFile):
                data = json.loads(value)
                with open(directory_path, 'w') as filename:
                    json.dump(data, filename, indent=1, sort_keys=True)
            if isinstance(data, TextFile):
                with open(directory_path, 'w', encoding='utf-8') as filename:
                    try:
                        filename.write(value)
                    except UnicodeEncodeError:
                        filename.write(value.encode('utf-8'))
        return True

    def get_media(self, image_path):
        """
        """
        theme_dir = self.directory_path
        image_path = os.path.join(theme_dir, image_path)
        image = open(image_path, 'rb')
        return image

    def save_css(self, name, content):
        """
        :param name:
        :param content:
        :return:
        """
        path = self.make_directory(name)
        with open(path, 'w') as file_name:
            file_name.write(content)
        return path

    def check_package_dot_json_presense(self, package_object):
        """
        """
        try:
            package_data_list = package_object.content
            for item in package_data_list:
                if item.name == PROJECT_JSON:
                    package_dict = json.loads(item.content)
                    dependency_list = []
                    try:
                        dependency_list = package_dict['dependencies']
                    except Exception:
                        pass
                    if dependency_list:
                        load_dependency(package_dict, {})
                    return True
        except Exception as exc:
            raise BlendedException(exc.args[0])

        return False

    def make_directory(self, path):
        """
        :param path:
        :return: return file name by checking and creating directories mentioned in the path if not already exists.
        """
        split_path = path.rsplit(os.sep, 1)
        if len(split_path) > 1:
            file_dir = split_path[0]
            file_name = split_path[1] + '.css'
            if not os.path.isdir(file_dir):
                os.makedirs(file_dir)
        path = os.path.join(file_dir, file_name)
        return path

    def download_media_concurrent_or_sequential(self, media_for_download=dict()):
        """
        Downloads the media files concurrently using multithreading if supported.
        media_for_download is a dictionary mapping.
        Ex. media_for_download[path] = URL hence, media_for_download.items() ---> [(path, url)...]
        If concurrent.futures is not supported, downloads media sequentially.
        """
        try:
            from concurrent.futures import ThreadPoolExecutor
        except:
            # concurrent.futures not supported. Lets download sequentially.
            for _tuple in media_for_download.items():
                self.download_and_save_media(_tuple)
        else:
            with ThreadPoolExecutor(64) as executor:
                executor.map(self.download_and_save_media, media_for_download.items())

    def download_and_save_media(self, url_path_tuple):
        """
        Downloads the image on specified path using the URL specified.
        """
        if not url_path_tuple:
            return
        path = url_path_tuple[0]
        url = url_path_tuple[1]
        response = urlopen(url, timeout=40)
        image_obj = response.read()
        with open(path, 'wb') as file:
            file.write(image_obj)



# coding: utf-8

"""
    Swagger Blended Hub API Explorer

    A collection of Swagger documentation for the Blended Hub APIs.

    OpenAPI spec version: 1.0.0
    Contact: api@blended.co
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from pprint import pformat
from six import iteritems
import re


class SharedPackageAccount(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, name=None, shared_account=None, pending=None, email=None, share_via_email=None, subscription=None, profile_picture=None, created_date=None):
        """
        SharedPackageAccount - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'shared_account': 'str',
            'pending': 'bool',
            'email': 'str',
            'share_via_email': 'bool',
            'subscription': 'str',
            'profile_picture': 'str',
            'created_date': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'shared_account': 'shared_account',
            'pending': 'pending',
            'email': 'email',
            'share_via_email': 'share_via_email',
            'subscription': 'subscription',
            'profile_picture': 'profile_picture',
            'created_date': 'created_date'
        }

        self._name = name
        self._shared_account = shared_account
        self._pending = pending
        self._email = email
        self._share_via_email = share_via_email
        self._subscription = subscription
        self._profile_picture = profile_picture
        self._created_date = created_date

    @property
    def name(self):
        """
        Gets the name of this SharedPackageAccount.
        Fully qualified name of the package which is shared.

        :return: The name of this SharedPackageAccount.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SharedPackageAccount.
        Fully qualified name of the package which is shared.

        :param name: The name of this SharedPackageAccount.
        :type: str
        """

        self._name = name

    @property
    def shared_account(self):
        """
        Gets the shared_account of this SharedPackageAccount.
        Account name with which package is shared

        :return: The shared_account of this SharedPackageAccount.
        :rtype: str
        """
        return self._shared_account

    @shared_account.setter
    def shared_account(self, shared_account):
        """
        Sets the shared_account of this SharedPackageAccount.
        Account name with which package is shared

        :param shared_account: The shared_account of this SharedPackageAccount.
        :type: str
        """

        self._shared_account = shared_account

    @property
    def pending(self):
        """
        Gets the pending of this SharedPackageAccount.
        If account account doesn't accepted the package it's value will be True else false

        :return: The pending of this SharedPackageAccount.
        :rtype: bool
        """
        return self._pending

    @pending.setter
    def pending(self, pending):
        """
        Sets the pending of this SharedPackageAccount.
        If account account doesn't accepted the package it's value will be True else false

        :param pending: The pending of this SharedPackageAccount.
        :type: bool
        """

        self._pending = pending

    @property
    def email(self):
        """
        Gets the email of this SharedPackageAccount.
        email of account or the email address of those were invited via email for sharing the package.

        :return: The email of this SharedPackageAccount.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this SharedPackageAccount.
        email of account or the email address of those were invited via email for sharing the package.

        :param email: The email of this SharedPackageAccount.
        :type: str
        """

        self._email = email

    @property
    def share_via_email(self):
        """
        Gets the share_via_email of this SharedPackageAccount.
        If package has been shared via email

        :return: The share_via_email of this SharedPackageAccount.
        :rtype: bool
        """
        return self._share_via_email

    @share_via_email.setter
    def share_via_email(self, share_via_email):
        """
        Sets the share_via_email of this SharedPackageAccount.
        If package has been shared via email

        :param share_via_email: The share_via_email of this SharedPackageAccount.
        :type: bool
        """

        self._share_via_email = share_via_email

    @property
    def subscription(self):
        """
        Gets the subscription of this SharedPackageAccount.
        subscription type of recipient account

        :return: The subscription of this SharedPackageAccount.
        :rtype: str
        """
        return self._subscription

    @subscription.setter
    def subscription(self, subscription):
        """
        Sets the subscription of this SharedPackageAccount.
        subscription type of recipient account

        :param subscription: The subscription of this SharedPackageAccount.
        :type: str
        """

        self._subscription = subscription

    @property
    def profile_picture(self):
        """
        Gets the profile_picture of this SharedPackageAccount.
        profile_picture of recipient

        :return: The profile_picture of this SharedPackageAccount.
        :rtype: str
        """
        return self._profile_picture

    @profile_picture.setter
    def profile_picture(self, profile_picture):
        """
        Sets the profile_picture of this SharedPackageAccount.
        profile_picture of recipient

        :param profile_picture: The profile_picture of this SharedPackageAccount.
        :type: str
        """

        self._profile_picture = profile_picture

    @property
    def created_date(self):
        """
        Gets the created_date of this SharedPackageAccount.
        created date when the package was shared

        :return: The created_date of this SharedPackageAccount.
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this SharedPackageAccount.
        created date when the package was shared

        :param created_date: The created_date of this SharedPackageAccount.
        :type: str
        """

        self._created_date = created_date

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



SRC = "src"
LIB = "lib"
INDEX_JSON = "_index.json"
PROJECT_JSON = "_package.json"
DEFAULT_ALIAS = "parent"
USER_RC = ".userrc"
PACKAGE_LIST_RC = ".packagelistrc"
CANONICAL_TXT = "canonical.txt"
HASH_TXT = ".hash.txt"
ALLOWED_IMAGE_TYPES = ['.jpg', '.jpeg', '.png']

RESTRICT_IMAGE_TYPE = ['.bmp', '.gif', '.tiff',
                       '.tif', '.ico', '.webp',
                       '.otf', '.eot', '.ttf',
                       '.woff', '.woff2']

# As below type is restricted on HUB. So I am doing this changes.
#ALLOWED_IMAGE_TYPES = ['.jpg', '.jpeg', '.bmp', '.gif',
#                       '.png', '.ico', '.webp',
#                       '.otf', '.eot', '.svg', '.ttf',
#                       '.woff', '.woff2']
#RESTRICT_IMAGE_TYPE = ['.tif', '.tiff']

IGNORE_EXTENSIONS = ('.swp', '.db', '~')
IGNORE_PREFIXES = (".", "_")

ALLOWED_FILE_TYPES = ['.html', '.css', '.bd', '.js', '.json', '.svg', '.txt']

CACHE_DICT = {}

BLENDED_ACCOUNT = 'blended'
BLENDED_BASIC = 'basic'
